# This file was automatically generated by SWIG (http://www.swig.org).
# Version 2.0.4
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.


"""
This is a wrapper for The CD Input and Control library (libcdio) which
encapsulates CD-ROM reading and control. Python programs wishing to be
oblivious of the OS- and device-dependent properties of a CD-ROM can
use this library.
"""


from sys import version_info
if version_info >= (2,6,0):
    def swig_import_helper():
        from os.path import dirname
        import imp
        fp = None
        try:
            fp, pathname, description = imp.find_module('_pycdio', [dirname(__file__)])
        except ImportError:
            import _pycdio
            return _pycdio
        if fp is not None:
            try:
                _mod = imp.load_module('_pycdio', fp, pathname, description)
            finally:
                fp.close()
            return _mod
    _pycdio = swig_import_helper()
    del swig_import_helper
else:
    import _pycdio
del version_info
try:
    _swig_property = property
except NameError:
    pass # Python < 2.2 doesn't have 'property'.
def _swig_setattr_nondynamic(self,class_type,name,value,static=1):
    if (name == "thisown"): return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name,None)
    if method: return method(self,value)
    if (not static):
        self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)

def _swig_setattr(self,class_type,name,value):
    return _swig_setattr_nondynamic(self,class_type,name,value,0)

def _swig_getattr(self,class_type,name):
    if (name == "thisown"): return self.this.own()
    method = class_type.__swig_getmethods__.get(name,None)
    if method: return method(self)
    raise AttributeError(name)

def _swig_repr(self):
    try: strthis = "proxy of " + self.this.__repr__()
    except: strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except AttributeError:
    class _object : pass
    _newclass = 0


class imaxdiv_t(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, imaxdiv_t, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, imaxdiv_t, name)
    __repr__ = _swig_repr
    __swig_setmethods__["quot"] = _pycdio.imaxdiv_t_quot_set
    __swig_getmethods__["quot"] = _pycdio.imaxdiv_t_quot_get
    if _newclass:quot = _swig_property(_pycdio.imaxdiv_t_quot_get, _pycdio.imaxdiv_t_quot_set)
    __swig_setmethods__["rem"] = _pycdio.imaxdiv_t_rem_set
    __swig_getmethods__["rem"] = _pycdio.imaxdiv_t_rem_get
    if _newclass:rem = _swig_property(_pycdio.imaxdiv_t_rem_get, _pycdio.imaxdiv_t_rem_set)
    def __init__(self): 
        """
        get_num_tracks(p_cdio)->int

        Return the number of tracks on the CD. 
        On error pycdio.INVALID_TRACK is returned.
        """
        this = _pycdio.new_imaxdiv_t()
        try: self.this.append(this)
        except: self.this = this
    __swig_destroy__ = _pycdio.delete_imaxdiv_t
    __del__ = lambda self : None;
imaxdiv_t_swigregister = _pycdio.imaxdiv_t_swigregister
imaxdiv_t_swigregister(imaxdiv_t)


def imaxabs(*args):
  return _pycdio.imaxabs(*args)
imaxabs = _pycdio.imaxabs

def imaxdiv(*args):
  return _pycdio.imaxdiv(*args)
imaxdiv = _pycdio.imaxdiv

def strtoimax(*args):
  return _pycdio.strtoimax(*args)
strtoimax = _pycdio.strtoimax

def strtoumax(*args):
  return _pycdio.strtoumax(*args)
strtoumax = _pycdio.strtoumax

def wcstoimax(*args):
  return _pycdio.wcstoimax(*args)
wcstoimax = _pycdio.wcstoimax

def wcstoumax(*args):
  return _pycdio.wcstoumax(*args)
wcstoumax = _pycdio.wcstoumax
VERSION_NUM = _pycdio.VERSION_NUM
INVALID_LBA = _pycdio.INVALID_LBA
INVALID_LSN = _pycdio.INVALID_LSN
CD_FRAMESIZE = _pycdio.CD_FRAMESIZE
CD_FRAMESIZE_RAW = _pycdio.CD_FRAMESIZE_RAW
ISO_BLOCKSIZE = _pycdio.ISO_BLOCKSIZE
M2F2_SECTOR_SIZE = _pycdio.M2F2_SECTOR_SIZE
M2RAW_SECTOR_SIZE = _pycdio.M2RAW_SECTOR_SIZE

def audio_pause(*args):
  """
    audio_pause(cdio)->status

    Pause playing CD through analog output.
    """
  return _pycdio.audio_pause(*args)

def audio_play_lsn(*args):
  """
    auto_play_lsn(cdio, start_lsn, end_lsn)->status

    Playing CD through analog output at the given lsn to the ending lsn
    """
  return _pycdio.audio_play_lsn(*args)

def audio_resume(*args):
  """
    audio_resume(cdio)->status
    Resume playing an audio CD.
    """
  return _pycdio.audio_resume(*args)

def audio_set_volume_levels(*args):
  """
    audio_resume(cdio)->status
    Resume playing an audio CD.
    """
  return _pycdio.audio_set_volume_levels(*args)

def audio_stop(*args):
  """
    audio_stop(cdio)->status
    Stop playing an audio CD.
    """
  return _pycdio.audio_stop(*args)
READ_MODE_AUDIO = _pycdio.READ_MODE_AUDIO
READ_MODE_M1F1 = _pycdio.READ_MODE_M1F1
READ_MODE_M1F2 = _pycdio.READ_MODE_M1F2
READ_MODE_M2F1 = _pycdio.READ_MODE_M2F1
READ_MODE_M2F2 = _pycdio.READ_MODE_M2F2

def lseek(*args):
  """
    lseek(cdio, offset, whence)->int
    Reposition read offset
    Similar to (if not the same as) libc's fseek()

    cdio is object to get adjested, offset is amount to seek and 
    whence is like corresponding parameter in libc's lseek, e.g. 
    it should be SEEK_SET or SEEK_END.

    the offset is returned or -1 on error.
    """
  return _pycdio.lseek(*args)

def read_cd(*args):
  """
    read_cd(cdio, size)->[size, data]

    Reads into buf the next size bytes.
    Similar to (if not the same as) libc's read()

    The number of reads read is returned. -1 is returned on error.
    """
  return _pycdio.read_cd(*args)

def read_sectors(*args):
  """
    read_sectors(bytes, lsn, read_mode)->[size, data]
    Reads a number of sectors (AKA blocks).
      
    lsn is sector to read, bytes is the number of bytes.

    If read_mode is pycdio.MODE_AUDIO, the return buffer size will be
    truncated to multiple of pycdio.CDIO_FRAMESIZE_RAW i_blocks bytes.

    If read_mode is pycdio.MODE_DATA, buffer will be truncated to a
    multiple of pycdio.ISO_BLOCKSIZE, pycdio.M1RAW_SECTOR_SIZE or
    pycdio.M2F2_SECTOR_SIZE bytes depending on what mode the data is in.
    If read_mode is pycdio.CDIO_MODE_M2F1, buffer will be truncated to a 
    multiple of pycdio.M2RAW_SECTOR_SIZE bytes.

    If read_mode is CDIO_MODE_M2F2, the return buffer size will be
    truncated to a multiple of pycdio.CD_FRAMESIZE bytes.

    If size <= 0 an error has occurred.
    """
  return _pycdio.read_sectors(*args)

def read_data_bytes(*args):
  """
    read_data_bytes(lsn, bytes)

    Reads a number of data sectors (AKA blocks).
      
    lsn is sector to read, bytes is the number of bytes.
    If you don't know whether you have a Mode 1/2, 
    Form 1/ Form 2/Formless sector best to reserve space for the maximum
    which is pycdio.M2RAW_SECTOR_SIZE.

    If size <= 0 an error has occurred.
    """
  return _pycdio.read_data_bytes(*args)
TRACK_FORMAT_AUDIO = _pycdio.TRACK_FORMAT_AUDIO
TRACK_FORMAT_CDI = _pycdio.TRACK_FORMAT_CDI
TRACK_FORMAT_XA = _pycdio.TRACK_FORMAT_XA
TRACK_FORMAT_DATA = _pycdio.TRACK_FORMAT_DATA
TRACK_FORMAT_PSX = _pycdio.TRACK_FORMAT_PSX
CDIO_TRACK_FLAG_FALSE = _pycdio.CDIO_TRACK_FLAG_FALSE
CDIO_TRACK_FLAG_TRUE = _pycdio.CDIO_TRACK_FLAG_TRUE
CDIO_TRACK_FLAG_ERROR = _pycdio.CDIO_TRACK_FLAG_ERROR
CDIO_TRACK_FLAG_UNKNOWN = _pycdio.CDIO_TRACK_FLAG_UNKNOWN
CDIO_CDROM_LBA = _pycdio.CDIO_CDROM_LBA
CDIO_CDROM_MSF = _pycdio.CDIO_CDROM_MSF
CDIO_CDROM_DATA_TRACK = _pycdio.CDIO_CDROM_DATA_TRACK
CDIO_CDROM_CDI_TRACK = _pycdio.CDIO_CDROM_CDI_TRACK
CDIO_CDROM_XA_TRACK = _pycdio.CDIO_CDROM_XA_TRACK
AUDIO = _pycdio.AUDIO
MODE1 = _pycdio.MODE1
MODE1_RAW = _pycdio.MODE1_RAW
MODE2 = _pycdio.MODE2
MODE2_FORM1 = _pycdio.MODE2_FORM1
MODE2_FORM2 = _pycdio.MODE2_FORM2
MODE2_FORM_MIX = _pycdio.MODE2_FORM_MIX
MODE2_RAW = _pycdio.MODE2_RAW
INVALID_TRACK = _pycdio.INVALID_TRACK
CDROM_LEADOUT_TRACK = _pycdio.CDROM_LEADOUT_TRACK

def get_first_track_num(*args):
  """
    get_first_track_num(p_cdio) -> int
    Get the number of the first track. 

    return the track number or pycdio.INVALID_TRACK if there was
    a problem.
    """
  return _pycdio.get_first_track_num(*args)

def get_last_track_num(*args):
  """
    get_last_track_num 
    Return the last track number.
    pycdio.INVALID_TRACK is if there was a problem.
    """
  return _pycdio.get_last_track_num(*args)

def get_track(*args):
  """
    cdio_get_track(lsn)->int

        Find the track which contains lsn.
        pycdio.INVALID_TRACK is returned if the lsn outside of the CD or
        if there was some error. 
        
        If the lsn is before the pregap of the first track, 0 is returned.
        Otherwise we return the track that spans the lsn.
    """
  return _pycdio.get_track(*args)

def get_track_channels(*args):
  """
    get_track_channels(cdio, track)->int

    Return number of channels in track: 2 or 4; -2 if implemented or -1
    for error.  Not meaningful if track is not an audio track.
    """
  return _pycdio.get_track_channels(*args)

def get_track_copy_permit(*args):
  """
    get_copy_permit(cdio, track)->int

    Return copy protection status on a track. Is this meaningful 
    not an audio track?

    """
  return _pycdio.get_track_copy_permit(*args)

def get_track_format(*args):
  """
    get_track_format(cdio, track)->format

    Get the format (audio, mode2, mode1) of track. 
    """
  return _pycdio.get_track_format(*args)

def is_track_green(*args):
  """
    is_track_green(cdio, track) -> bool

    Return True if we have XA data (green, mode2 form1) or
    XA data (green, mode2 form2). That is track begins:
     sync - header - subheader
    12     4      -  8
        
    FIXME: there's gotta be a better design for this and get_track_format?
    """
  return _pycdio.is_track_green(*args)

def get_track_last_lsn(*args):
  """
    cdio_get_track_last_lsn(cdio, track)->lsn

    Return the ending LSN for track number
    track in cdio.  CDIO_INVALID_LSN is returned on error.
    """
  return _pycdio.get_track_last_lsn(*args)

def get_track_lba(*args):
  """
    cdio_get_track_lba  
        Get the starting LBA for track number
        i_track in p_cdio.  Track numbers usually start at something 
        greater than 0, usually 1.

        The 'leadout' track is specified either by
        using i_track CDIO_CDROM_LEADOUT_TRACK or the total tracks+1.

        @param p_cdio object to get information from
        @param i_track  the track number we want the LSN for
        @return the starting LBA or CDIO_INVALID_LBA on error.
    """
  return _pycdio.get_track_lba(*args)

def get_track_lsn(*args):
  """
    cdio_get_track_lsn (cdio, track)->int

    Return the starting LSN for track number. 
    Track numbers usually start at something greater than 0, usually 1.

    The 'leadout' track is specified either by
    using i_track pycdio.CDROM_LEADOUT_TRACK or the total tracks+1.

    pycdio.INVALID_LSN is returned on error.
    """
  return _pycdio.get_track_lsn(*args)

def get_track_msf(*args):
  """
    get_track_msf(cdio,track)->string

      Return the starting MSF (minutes/secs/frames) for track number
      track.  Track numbers usually start at something 
      greater than 0, usually 1.

      The 'leadout' track is specified either by
      using i_track CDIO_CDROM_LEADOUT_TRACK or the total tracks+1.
        
    @return string mm:ss:ff if all good, or string 'error' on error.
    """
  return _pycdio.get_track_msf(*args)

def get_track_preemphasis(*args):
  """
    cdio_get_track_preemphasis(cdio, track)

    Get linear preemphasis status on an audio track.
    This is not meaningful if not an audio track?
    """
  return _pycdio.get_track_preemphasis(*args)

def get_track_sec_count(*args):
  """
    get_track_sec_count(cdio, track)->int

    Get the number of sectors between this track an the next.  This
    includes any pregap sectors before the start of the next track.
    Track numbers usually start at something 
    greater than 0, usually 1.

    0 is returned if there is an error.
    """
  return _pycdio.get_track_sec_count(*args)
CDTEXT_ARRANGER = _pycdio.CDTEXT_ARRANGER
CDTEXT_COMPOSER = _pycdio.CDTEXT_COMPOSER
CDTEXT_DISCID = _pycdio.CDTEXT_DISCID
CDTEXT_ISRC = _pycdio.CDTEXT_ISRC
CDTEXT_MESSAGE = _pycdio.CDTEXT_MESSAGE
CDTEXT_PERFORMER = _pycdio.CDTEXT_PERFORMER
CDTEXT_FIELD_TITLE = _pycdio.CDTEXT_FIELD_TITLE
CDTEXT_FIELD_SONGWRITER = _pycdio.CDTEXT_FIELD_SONGWRITER
CDTEXT_FIELD_UPC_EAN = _pycdio.CDTEXT_FIELD_UPC_EAN
CDTEXT_GENRE = _pycdio.CDTEXT_GENRE
CDTEXT_FIELD_INVALID = _pycdio.CDTEXT_FIELD_INVALID
CDTEXT_GENRE_UNUSED = _pycdio.CDTEXT_GENRE_UNUSED
CDTEXT_GENRE_UNDEFINED = _pycdio.CDTEXT_GENRE_UNDEFINED
CDTEXT_GENRE_ADULT_CONTEMP = _pycdio.CDTEXT_GENRE_ADULT_CONTEMP
CDTEXT_GENRE_ALT_ROCK = _pycdio.CDTEXT_GENRE_ALT_ROCK
CDTEXT_GENRE_CHILDRENS = _pycdio.CDTEXT_GENRE_CHILDRENS
CDTEXT_GENRE_CLASSIC = _pycdio.CDTEXT_GENRE_CLASSIC
CDTEXT_GENRE_CHRIST_CONTEMP = _pycdio.CDTEXT_GENRE_CHRIST_CONTEMP
CDTEXT_GENRE_COUNTRY = _pycdio.CDTEXT_GENRE_COUNTRY
CDTEXT_GENRE_DANCE = _pycdio.CDTEXT_GENRE_DANCE
CDTEXT_GENRE_EASY_LISTENING = _pycdio.CDTEXT_GENRE_EASY_LISTENING
CDTEXT_GENRE_EROTIC = _pycdio.CDTEXT_GENRE_EROTIC
CDTEXT_GENRE_FOLK = _pycdio.CDTEXT_GENRE_FOLK
CDTEXT_GENRE_GOSPEL = _pycdio.CDTEXT_GENRE_GOSPEL
CDTEXT_GENRE_HIPHOP = _pycdio.CDTEXT_GENRE_HIPHOP
CDTEXT_GENRE_JAZZ = _pycdio.CDTEXT_GENRE_JAZZ
CDTEXT_GENRE_LATIN = _pycdio.CDTEXT_GENRE_LATIN
CDTEXT_GENRE_MUSICAL = _pycdio.CDTEXT_GENRE_MUSICAL
CDTEXT_GENRE_NEWAGE = _pycdio.CDTEXT_GENRE_NEWAGE
CDTEXT_GENRE_OPERA = _pycdio.CDTEXT_GENRE_OPERA
CDTEXT_GENRE_OPERETTA = _pycdio.CDTEXT_GENRE_OPERETTA
CDTEXT_GENRE_POP = _pycdio.CDTEXT_GENRE_POP
CDTEXT_GENRE_RAP = _pycdio.CDTEXT_GENRE_RAP
CDTEXT_GENRE_REGGAE = _pycdio.CDTEXT_GENRE_REGGAE
CDTEXT_GENRE_ROCK = _pycdio.CDTEXT_GENRE_ROCK
CDTEXT_GENRE_RYTHMANDBLUES = _pycdio.CDTEXT_GENRE_RYTHMANDBLUES
CDTEXT_GENRE_SOUNDEFFECTS = _pycdio.CDTEXT_GENRE_SOUNDEFFECTS
CDTEXT_GENRE_SOUNDTRACK = _pycdio.CDTEXT_GENRE_SOUNDTRACK
CDTEXT_GENRE_SPOKEN_WORD = _pycdio.CDTEXT_GENRE_SPOKEN_WORD
CDTEXT_GENRE_WORLD_MUSIC = _pycdio.CDTEXT_GENRE_WORLD_MUSIC
CDTEXT_LANGUAGE_UNKNOWN = _pycdio.CDTEXT_LANGUAGE_UNKNOWN
CDTEXT_LANGUAGE_ALBANIAN = _pycdio.CDTEXT_LANGUAGE_ALBANIAN
CDTEXT_LANGUAGE_BRETON = _pycdio.CDTEXT_LANGUAGE_BRETON
CDTEXT_LANGUAGE_CATALAN = _pycdio.CDTEXT_LANGUAGE_CATALAN
CDTEXT_LANGUAGE_CROATIAN = _pycdio.CDTEXT_LANGUAGE_CROATIAN
CDTEXT_LANGUAGE_WELSH = _pycdio.CDTEXT_LANGUAGE_WELSH
CDTEXT_LANGUAGE_CZECH = _pycdio.CDTEXT_LANGUAGE_CZECH
CDTEXT_LANGUAGE_DANISH = _pycdio.CDTEXT_LANGUAGE_DANISH
CDTEXT_LANGUAGE_GERMAN = _pycdio.CDTEXT_LANGUAGE_GERMAN
CDTEXT_LANGUAGE_ENGLISH = _pycdio.CDTEXT_LANGUAGE_ENGLISH
CDTEXT_LANGUAGE_SPANISH = _pycdio.CDTEXT_LANGUAGE_SPANISH
CDTEXT_LANGUAGE_ESPERANTO = _pycdio.CDTEXT_LANGUAGE_ESPERANTO
CDTEXT_LANGUAGE_ESTONIAN = _pycdio.CDTEXT_LANGUAGE_ESTONIAN
CDTEXT_LANGUAGE_BASQUE = _pycdio.CDTEXT_LANGUAGE_BASQUE
CDTEXT_LANGUAGE_FAROESE = _pycdio.CDTEXT_LANGUAGE_FAROESE
CDTEXT_LANGUAGE_FRENCH = _pycdio.CDTEXT_LANGUAGE_FRENCH
CDTEXT_LANGUAGE_FRISIAN = _pycdio.CDTEXT_LANGUAGE_FRISIAN
CDTEXT_LANGUAGE_IRISH = _pycdio.CDTEXT_LANGUAGE_IRISH
CDTEXT_LANGUAGE_GAELIC = _pycdio.CDTEXT_LANGUAGE_GAELIC
CDTEXT_LANGUAGE_GALICIAN = _pycdio.CDTEXT_LANGUAGE_GALICIAN
CDTEXT_LANGUAGE_ICELANDIC = _pycdio.CDTEXT_LANGUAGE_ICELANDIC
CDTEXT_LANGUAGE_ITALIAN = _pycdio.CDTEXT_LANGUAGE_ITALIAN
CDTEXT_LANGUAGE_LAPPISH = _pycdio.CDTEXT_LANGUAGE_LAPPISH
CDTEXT_LANGUAGE_LATIN = _pycdio.CDTEXT_LANGUAGE_LATIN
CDTEXT_LANGUAGE_LATVIAN = _pycdio.CDTEXT_LANGUAGE_LATVIAN
CDTEXT_LANGUAGE_LUXEMBOURGIAN = _pycdio.CDTEXT_LANGUAGE_LUXEMBOURGIAN
CDTEXT_LANGUAGE_LITHUANIAN = _pycdio.CDTEXT_LANGUAGE_LITHUANIAN
CDTEXT_LANGUAGE_HUNGARIAN = _pycdio.CDTEXT_LANGUAGE_HUNGARIAN
CDTEXT_LANGUAGE_MALTESE = _pycdio.CDTEXT_LANGUAGE_MALTESE
CDTEXT_LANGUAGE_DUTCH = _pycdio.CDTEXT_LANGUAGE_DUTCH
CDTEXT_LANGUAGE_NORWEGIAN = _pycdio.CDTEXT_LANGUAGE_NORWEGIAN
CDTEXT_LANGUAGE_OCCITAN = _pycdio.CDTEXT_LANGUAGE_OCCITAN
CDTEXT_LANGUAGE_POLISH = _pycdio.CDTEXT_LANGUAGE_POLISH
CDTEXT_LANGUAGE_PORTUGUESE = _pycdio.CDTEXT_LANGUAGE_PORTUGUESE
CDTEXT_LANGUAGE_ROMANIAN = _pycdio.CDTEXT_LANGUAGE_ROMANIAN
CDTEXT_LANGUAGE_ROMANSH = _pycdio.CDTEXT_LANGUAGE_ROMANSH
CDTEXT_LANGUAGE_SERBIAN = _pycdio.CDTEXT_LANGUAGE_SERBIAN
CDTEXT_LANGUAGE_SLOVAK = _pycdio.CDTEXT_LANGUAGE_SLOVAK
CDTEXT_LANGUAGE_SLOVENIAN = _pycdio.CDTEXT_LANGUAGE_SLOVENIAN
CDTEXT_LANGUAGE_FINNISH = _pycdio.CDTEXT_LANGUAGE_FINNISH
CDTEXT_LANGUAGE_SWEDISH = _pycdio.CDTEXT_LANGUAGE_SWEDISH
CDTEXT_LANGUAGE_TURKISH = _pycdio.CDTEXT_LANGUAGE_TURKISH
CDTEXT_LANGUAGE_FLEMISH = _pycdio.CDTEXT_LANGUAGE_FLEMISH
CDTEXT_LANGUAGE_WALLON = _pycdio.CDTEXT_LANGUAGE_WALLON
CDTEXT_LANGUAGE_ZULU = _pycdio.CDTEXT_LANGUAGE_ZULU
CDTEXT_LANGUAGE_VIETNAMESE = _pycdio.CDTEXT_LANGUAGE_VIETNAMESE
CDTEXT_LANGUAGE_UZBEK = _pycdio.CDTEXT_LANGUAGE_UZBEK
CDTEXT_LANGUAGE_URDU = _pycdio.CDTEXT_LANGUAGE_URDU
CDTEXT_LANGUAGE_UKRAINIAN = _pycdio.CDTEXT_LANGUAGE_UKRAINIAN
CDTEXT_LANGUAGE_THAI = _pycdio.CDTEXT_LANGUAGE_THAI
CDTEXT_LANGUAGE_TELUGU = _pycdio.CDTEXT_LANGUAGE_TELUGU
CDTEXT_LANGUAGE_TATAR = _pycdio.CDTEXT_LANGUAGE_TATAR
CDTEXT_LANGUAGE_TAMIL = _pycdio.CDTEXT_LANGUAGE_TAMIL
CDTEXT_LANGUAGE_TADZHIK = _pycdio.CDTEXT_LANGUAGE_TADZHIK
CDTEXT_LANGUAGE_SWAHILI = _pycdio.CDTEXT_LANGUAGE_SWAHILI
CDTEXT_LANGUAGE_SRANANTONGO = _pycdio.CDTEXT_LANGUAGE_SRANANTONGO
CDTEXT_LANGUAGE_SOMALI = _pycdio.CDTEXT_LANGUAGE_SOMALI
CDTEXT_LANGUAGE_SINHALESE = _pycdio.CDTEXT_LANGUAGE_SINHALESE
CDTEXT_LANGUAGE_SHONA = _pycdio.CDTEXT_LANGUAGE_SHONA
CDTEXT_LANGUAGE_SERBO_CROAT = _pycdio.CDTEXT_LANGUAGE_SERBO_CROAT
CDTEXT_LANGUAGE_RUTHENIAN = _pycdio.CDTEXT_LANGUAGE_RUTHENIAN
CDTEXT_LANGUAGE_RUSSIAN = _pycdio.CDTEXT_LANGUAGE_RUSSIAN
CDTEXT_LANGUAGE_QUECHUA = _pycdio.CDTEXT_LANGUAGE_QUECHUA
CDTEXT_LANGUAGE_PUSHTU = _pycdio.CDTEXT_LANGUAGE_PUSHTU
CDTEXT_LANGUAGE_PUNJABI = _pycdio.CDTEXT_LANGUAGE_PUNJABI
CDTEXT_LANGUAGE_PERSIAN = _pycdio.CDTEXT_LANGUAGE_PERSIAN
CDTEXT_LANGUAGE_PAPAMIENTO = _pycdio.CDTEXT_LANGUAGE_PAPAMIENTO
CDTEXT_LANGUAGE_ORIYA = _pycdio.CDTEXT_LANGUAGE_ORIYA
CDTEXT_LANGUAGE_NEPALI = _pycdio.CDTEXT_LANGUAGE_NEPALI
CDTEXT_LANGUAGE_NDEBELE = _pycdio.CDTEXT_LANGUAGE_NDEBELE
CDTEXT_LANGUAGE_MARATHI = _pycdio.CDTEXT_LANGUAGE_MARATHI
CDTEXT_LANGUAGE_MOLDAVIAN = _pycdio.CDTEXT_LANGUAGE_MOLDAVIAN
CDTEXT_LANGUAGE_MALAYSIAN = _pycdio.CDTEXT_LANGUAGE_MALAYSIAN
CDTEXT_LANGUAGE_MALAGASAY = _pycdio.CDTEXT_LANGUAGE_MALAGASAY
CDTEXT_LANGUAGE_MACEDONIAN = _pycdio.CDTEXT_LANGUAGE_MACEDONIAN
CDTEXT_LANGUAGE_LAOTIAN = _pycdio.CDTEXT_LANGUAGE_LAOTIAN
CDTEXT_LANGUAGE_KOREAN = _pycdio.CDTEXT_LANGUAGE_KOREAN
CDTEXT_LANGUAGE_KHMER = _pycdio.CDTEXT_LANGUAGE_KHMER
CDTEXT_LANGUAGE_KAZAKH = _pycdio.CDTEXT_LANGUAGE_KAZAKH
CDTEXT_LANGUAGE_KANNADA = _pycdio.CDTEXT_LANGUAGE_KANNADA
CDTEXT_LANGUAGE_JAPANESE = _pycdio.CDTEXT_LANGUAGE_JAPANESE
CDTEXT_LANGUAGE_INDONESIAN = _pycdio.CDTEXT_LANGUAGE_INDONESIAN
CDTEXT_LANGUAGE_HINDI = _pycdio.CDTEXT_LANGUAGE_HINDI
CDTEXT_LANGUAGE_HEBREW = _pycdio.CDTEXT_LANGUAGE_HEBREW
CDTEXT_LANGUAGE_HAUSA = _pycdio.CDTEXT_LANGUAGE_HAUSA
CDTEXT_LANGUAGE_GURANI = _pycdio.CDTEXT_LANGUAGE_GURANI
CDTEXT_LANGUAGE_GUJURATI = _pycdio.CDTEXT_LANGUAGE_GUJURATI
CDTEXT_LANGUAGE_GREEK = _pycdio.CDTEXT_LANGUAGE_GREEK
CDTEXT_LANGUAGE_GEORGIAN = _pycdio.CDTEXT_LANGUAGE_GEORGIAN
CDTEXT_LANGUAGE_FULANI = _pycdio.CDTEXT_LANGUAGE_FULANI
CDTEXT_LANGUAGE_DARI = _pycdio.CDTEXT_LANGUAGE_DARI
CDTEXT_LANGUAGE_CHURASH = _pycdio.CDTEXT_LANGUAGE_CHURASH
CDTEXT_LANGUAGE_CHINESE = _pycdio.CDTEXT_LANGUAGE_CHINESE
CDTEXT_LANGUAGE_BURMESE = _pycdio.CDTEXT_LANGUAGE_BURMESE
CDTEXT_LANGUAGE_BULGARIAN = _pycdio.CDTEXT_LANGUAGE_BULGARIAN
CDTEXT_LANGUAGE_BENGALI = _pycdio.CDTEXT_LANGUAGE_BENGALI
CDTEXT_LANGUAGE_BIELORUSSIAN = _pycdio.CDTEXT_LANGUAGE_BIELORUSSIAN
CDTEXT_LANGUAGE_BAMBORA = _pycdio.CDTEXT_LANGUAGE_BAMBORA
CDTEXT_LANGUAGE_AZERBAIJANI = _pycdio.CDTEXT_LANGUAGE_AZERBAIJANI
CDTEXT_LANGUAGE_ASSAMESE = _pycdio.CDTEXT_LANGUAGE_ASSAMESE
CDTEXT_LANGUAGE_ARMENIAN = _pycdio.CDTEXT_LANGUAGE_ARMENIAN
CDTEXT_LANGUAGE_ARABIC = _pycdio.CDTEXT_LANGUAGE_ARABIC
CDTEXT_LANGUAGE_AMHARIC = _pycdio.CDTEXT_LANGUAGE_AMHARIC
MIN_CDTEXT_FIELD = _pycdio.MIN_CDTEXT_FIELD
MAX_CDTEXT_FIELDS = _pycdio.MAX_CDTEXT_FIELDS

def cdtext_field2str(*args):
  """cdtext_field2str(cdtext_field_t i) -> char"""
  return _pycdio.cdtext_field2str(*args)

def cdtext_lang2str(*args):
  """cdtext_lang2str(cdtext_lang_t i) -> char"""
  return _pycdio.cdtext_lang2str(*args)

def cdtext_genre2str(*args):
  """cdtext_genre2str(cdtext_genre_t i) -> char"""
  return _pycdio.cdtext_genre2str(*args)

def cdtext_init():
  """cdtext_init() -> cdtext_t"""
  return _pycdio.cdtext_init()

def cdtext_destroy(*args):
  """cdtext_destroy(cdtext_t p_cdtext)"""
  return _pycdio.cdtext_destroy(*args)

def cdtext_get(*args):
  """cdtext_get(cdtext_t p_cdtext, cdtext_field_t key, track_t track) -> char"""
  return _pycdio.cdtext_get(*args)

def cdtext_get_const(*args):
  """cdtext_get_const(cdtext_t p_cdtext, cdtext_field_t key, track_t track) -> char"""
  return _pycdio.cdtext_get_const(*args)

def cdtext_get_language(*args):
  """cdtext_get_language(cdtext_t p_cdtext) -> cdtext_lang_t"""
  return _pycdio.cdtext_get_language(*args)

def cdtext_select_language(*args):
  """cdtext_select_language(cdtext_t p_cdtext, cdtext_lang_t lang) -> bool"""
  return _pycdio.cdtext_select_language(*args)

def cdtext_list_languages(*args):
  """cdtext_list_languages(cdtext_t p_cdtext) -> cdtext_lang_t"""
  return _pycdio.cdtext_list_languages(*args)

def cdtext_set(*args):
  """
    cdtext_set(cdtext_t p_cdtext, cdtext_field_t key, uint8_t value, 
        track_t track, char charset)
    """
  return _pycdio.cdtext_set(*args)

def get_cdtext(*args):
  """get_cdtext(CdIo_t p_cdio) -> cdtext_t"""
  return _pycdio.get_cdtext(*args)
DRIVE_CAP_ERROR = _pycdio.DRIVE_CAP_ERROR
DRIVE_CAP_UNKNOWN = _pycdio.DRIVE_CAP_UNKNOWN
DRIVE_CAP_MISC_CLOSE_TRAY = _pycdio.DRIVE_CAP_MISC_CLOSE_TRAY
DRIVE_CAP_MISC_EJECT = _pycdio.DRIVE_CAP_MISC_EJECT
DRIVE_CAP_MISC_LOCK = _pycdio.DRIVE_CAP_MISC_LOCK
DRIVE_CAP_MISC_SELECT_SPEED = _pycdio.DRIVE_CAP_MISC_SELECT_SPEED
DRIVE_CAP_MISC_SELECT_DISC = _pycdio.DRIVE_CAP_MISC_SELECT_DISC
DRIVE_CAP_MISC_MULTI_SESSION = _pycdio.DRIVE_CAP_MISC_MULTI_SESSION
DRIVE_CAP_MISC_MEDIA_CHANGED = _pycdio.DRIVE_CAP_MISC_MEDIA_CHANGED
DRIVE_CAP_MISC_RESET = _pycdio.DRIVE_CAP_MISC_RESET
DRIVE_CAP_MISC_FILE = _pycdio.DRIVE_CAP_MISC_FILE
DRIVE_CAP_READ_AUDIO = _pycdio.DRIVE_CAP_READ_AUDIO
DRIVE_CAP_READ_CD_DA = _pycdio.DRIVE_CAP_READ_CD_DA
DRIVE_CAP_READ_CD_G = _pycdio.DRIVE_CAP_READ_CD_G
DRIVE_CAP_READ_CD_R = _pycdio.DRIVE_CAP_READ_CD_R
DRIVE_CAP_READ_CD_RW = _pycdio.DRIVE_CAP_READ_CD_RW
DRIVE_CAP_READ_DVD_R = _pycdio.DRIVE_CAP_READ_DVD_R
DRIVE_CAP_READ_DVD_PR = _pycdio.DRIVE_CAP_READ_DVD_PR
DRIVE_CAP_READ_DVD_RAM = _pycdio.DRIVE_CAP_READ_DVD_RAM
DRIVE_CAP_READ_DVD_ROM = _pycdio.DRIVE_CAP_READ_DVD_ROM
DRIVE_CAP_READ_DVD_RW = _pycdio.DRIVE_CAP_READ_DVD_RW
DRIVE_CAP_READ_DVD_RPW = _pycdio.DRIVE_CAP_READ_DVD_RPW
DRIVE_CAP_READ_C2_ERRS = _pycdio.DRIVE_CAP_READ_C2_ERRS
DRIVE_CAP_READ_MODE2_FORM1 = _pycdio.DRIVE_CAP_READ_MODE2_FORM1
DRIVE_CAP_READ_MODE2_FORM2 = _pycdio.DRIVE_CAP_READ_MODE2_FORM2
DRIVE_CAP_READ_MCN = _pycdio.DRIVE_CAP_READ_MCN
DRIVE_CAP_READ_ISRC = _pycdio.DRIVE_CAP_READ_ISRC
DRIVE_CAP_WRITE_CD_R = _pycdio.DRIVE_CAP_WRITE_CD_R
DRIVE_CAP_WRITE_CD_RW = _pycdio.DRIVE_CAP_WRITE_CD_RW
DRIVE_CAP_WRITE_DVD_R = _pycdio.DRIVE_CAP_WRITE_DVD_R
DRIVE_CAP_WRITE_DVD_PR = _pycdio.DRIVE_CAP_WRITE_DVD_PR
DRIVE_CAP_WRITE_DVD_RAM = _pycdio.DRIVE_CAP_WRITE_DVD_RAM
DRIVE_CAP_WRITE_DVD_RW = _pycdio.DRIVE_CAP_WRITE_DVD_RW
DRIVE_CAP_WRITE_DVD_RPW = _pycdio.DRIVE_CAP_WRITE_DVD_RPW
DRIVE_CAP_WRITE_MT_RAINIER = _pycdio.DRIVE_CAP_WRITE_MT_RAINIER
DRIVE_CAP_WRITE_BURN_PROOF = _pycdio.DRIVE_CAP_WRITE_BURN_PROOF
DRIVE_CAP_WRITE_CD = _pycdio.DRIVE_CAP_WRITE_CD
DRIVE_CAP_WRITE_DVD = _pycdio.DRIVE_CAP_WRITE_DVD
DRIVE_CAP_WRITE = _pycdio.DRIVE_CAP_WRITE
MMC_HW_VENDOR_LEN = _pycdio.MMC_HW_VENDOR_LEN
MMC_HW_MODEL_LEN = _pycdio.MMC_HW_MODEL_LEN
MMC_HW_REVISION_LEN = _pycdio.MMC_HW_REVISION_LEN
SRC_IS_DISK_IMAGE_MASK = _pycdio.SRC_IS_DISK_IMAGE_MASK
SRC_IS_DEVICE_MASK = _pycdio.SRC_IS_DEVICE_MASK
SRC_IS_SCSI_MASK = _pycdio.SRC_IS_SCSI_MASK
SRC_IS_NATIVE_MASK = _pycdio.SRC_IS_NATIVE_MASK
DRIVER_UNKNOWN = _pycdio.DRIVER_UNKNOWN
DRIVER_AIX = _pycdio.DRIVER_AIX
DRIVER_BSDI = _pycdio.DRIVER_BSDI
DRIVER_FREEBSD = _pycdio.DRIVER_FREEBSD
DRIVER_LINUX = _pycdio.DRIVER_LINUX
DRIVER_SOLARIS = _pycdio.DRIVER_SOLARIS
DRIVER_OSX = _pycdio.DRIVER_OSX
DRIVER_NETBSD = _pycdio.DRIVER_NETBSD
DRIVER_WIN32 = _pycdio.DRIVER_WIN32
DRIVER_CDRDAO = _pycdio.DRIVER_CDRDAO
DRIVER_BINCUE = _pycdio.DRIVER_BINCUE
DRIVER_NRG = _pycdio.DRIVER_NRG
DRIVER_DEVICE = _pycdio.DRIVER_DEVICE
DRIVER_OP_SUCCESS = _pycdio.DRIVER_OP_SUCCESS
DRIVER_OP_ERROR = _pycdio.DRIVER_OP_ERROR
DRIVER_OP_UNSUPPORTED = _pycdio.DRIVER_OP_UNSUPPORTED
DRIVER_OP_UNINIT = _pycdio.DRIVER_OP_UNINIT
DRIVER_OP_NOT_PERMITTED = _pycdio.DRIVER_OP_NOT_PERMITTED
DRIVER_OP_BAD_PARAMETER = _pycdio.DRIVER_OP_BAD_PARAMETER
DRIVER_OP_BAD_POINTER = _pycdio.DRIVER_OP_BAD_POINTER
DRIVER_OP_NO_DRIVER = _pycdio.DRIVER_OP_NO_DRIVER
FS_AUDIO = _pycdio.FS_AUDIO
FS_HIGH_SIERRA = _pycdio.FS_HIGH_SIERRA
FS_ISO_9660 = _pycdio.FS_ISO_9660
FS_INTERACTIVE = _pycdio.FS_INTERACTIVE
FS_HFS = _pycdio.FS_HFS
FS_UFS = _pycdio.FS_UFS
FS_EXT2 = _pycdio.FS_EXT2
FS_ISO_HFS = _pycdio.FS_ISO_HFS
FS_ISO_9660_INTERACTIVE = _pycdio.FS_ISO_9660_INTERACTIVE
FS_3DO = _pycdio.FS_3DO
FS_XISO = _pycdio.FS_XISO
FS_UDFX = _pycdio.FS_UDFX
FS_UDF = _pycdio.FS_UDF
FS_ISO_UDF = _pycdio.FS_ISO_UDF
FS_ANAL_XA = _pycdio.FS_ANAL_XA
FS_ANAL_MULTISESSION = _pycdio.FS_ANAL_MULTISESSION
FS_ANAL_PHOTO_CD = _pycdio.FS_ANAL_PHOTO_CD
FS_ANAL_HIDDEN_TRACK = _pycdio.FS_ANAL_HIDDEN_TRACK
FS_ANAL_CDTV = _pycdio.FS_ANAL_CDTV
FS_ANAL_BOOTABLE = _pycdio.FS_ANAL_BOOTABLE
FS_ANAL_VIDEOCD = _pycdio.FS_ANAL_VIDEOCD
FS_ANAL_ROCKRIDGE = _pycdio.FS_ANAL_ROCKRIDGE
FS_ANAL_JOLIET = _pycdio.FS_ANAL_JOLIET
FS_ANAL_SVCD = _pycdio.FS_ANAL_SVCD
FS_ANAL_CVD = _pycdio.FS_ANAL_CVD
FS_ANAL_XISO = _pycdio.FS_ANAL_XISO
FS_MATCH_ALL = _pycdio.FS_MATCH_ALL
FS_UNKNOWN = _pycdio.FS_UNKNOWN

def close_tray(*args):
  """
    close_tray(drive=None, driver_id=None) -> [status, driver_id]

    close media tray in CD drive if there is a routine to do so. 
    The driver id is returned. An exception is thrown on error.
    """
  return _pycdio.close_tray(*args)

def close(*args):
  """
    destroy(p_cdio)
    Free resources associated with p_cdio.  Call this when done using
    using CD reading/control operations for the current device.

    """
  return _pycdio.close(*args)

def eject_media(*args):
  """
    eject_media(cdio)->return_code

    Eject media in CD drive if there is a routine to do so. 

    """
  return _pycdio.eject_media(*args)

def eject_media_drive(psz_drive = None):
  """
    eject_media_drive(drive=None)->return_code
    Eject media in CD drive if there is a routine to do so. 
      
    psz_drive: the name of the device to be acted upon. 
    The operation status is returned.
    """
  return _pycdio.eject_media_drive(psz_drive)

def get_arg(*args):
  """
    get_arg(p_cdio, key)->string

    Get the value associatied with key.
    """
  return _pycdio.get_arg(*args)

def get_device(p_cdio = None):
  """
    get_device(cdio)->str

    Get the CD device associated with cdio.
    If cdio is NULL (we haven't initialized a specific device driver), 
    then find a suitable one and return the default device for that.
        
    In some situations of drivers or OS's we can't find a CD device if
    there is no media in it and it is possible for this routine to return
    None even though there may be a hardware CD-ROM.
    """
  return _pycdio.get_device(p_cdio)

def get_default_device_driver(*args):
  """
    get_default_device_driver(driver_id=None)->[device, driver]
    Return a string containing the default CD device if none is specified.
    if p_driver_id is DRIVER_UNKNOWN or DRIVER_DEVICE then find a suitable
    one set the default device for that.
        
    None is returned as the device if we couldn't get a default device.
    """
  return _pycdio.get_default_device_driver(*args)

def get_devices(*args):
  """
    get_devices(driver_id)->[device1, device2, ...]

    Get an list of device names.
    """
  return _pycdio.get_devices(*args)

def get_devices_ret(*args):
  """
    get_devices_ret(driver_id)->[device1, device2, ... driver_id]

    Like get_devices, but return the p_driver_id which may be different
    from the passed-in driver_id if it was pycdio.DRIVER_DEVICE or
    pycdio.DRIVER_UNKNOWN. The return driver_id may be useful because
    often one wants to get a drive name and then *open* it
    afterwards. Giving the driver back facilitates this, and speeds things
    up for libcdio as well.
    """
  return _pycdio.get_devices_ret(*args)

def get_devices_with_cap(*args):
  """
    get_devices_with_cap(capabilities, any)->[device1, device2...]
    Get an array of device names in search_devices that have at least
    the capabilities listed by the capabities parameter.  
        
    If any is False then every capability listed in the
    extended portion of capabilities (i.e. not the basic filesystem)
    must be satisified. If any is True, then if any of the
    capabilities matches, we call that a success.

    To find a CD-drive of any type, use the mask pycdio.CDIO_FS_MATCH_ALL.

    The array of device names is returned or NULL if we couldn't get a
    default device.  It is also possible to return a non NULL but after
    dereferencing the the value is NULL. This also means nothing was
    found.
    """
  return _pycdio.get_devices_with_cap(*args)

def get_devices_with_cap_ret(*args):
  """
    Like cdio_get_devices_with_cap but we return the driver we found
    as well. This is because often one wants to search for kind of drive
    and then *open* it afterwards. Giving the driver back facilitates this,
      and speeds things up for libcdio as well.
    """
  return _pycdio.get_devices_with_cap_ret(*args)

def get_driver_name(*args):
  """
    get_driver_name(cdio)-> string

    return a string containing the name of the driver in use.

    An IOError exception is raised on error.

    """
  return _pycdio.get_driver_name(*args)

def get_driver_id(*args):
  """
    get_driver_id(cdio)-> int

    Return the driver id of the driver in use.
    if cdio has not been initialized or is None, 
    return pycdio.DRIVER_UNKNOWN.
    """
  return _pycdio.get_driver_id(*args)

def get_last_session(*args):
  """
    get_last_session(p_cdio) -> int
    Get the LSN of the first track of the last session of on the CD.
    An exception is thrown on error.
    """
  return _pycdio.get_last_session(*args)

def have_driver(*args):
  """
    have_driver(driver_id) -> int

    Return 1 if we have driver driver_id, 0 if not and -1 
    if driver id is out of range.
    """
  return _pycdio.have_driver(*args)

def have_ATAPI(*args):
  """
    have_ATAPI(CdIo_t *p_cdio)->bool
    return True if CD-ROM understand ATAPI commands.
    """
  return _pycdio.have_ATAPI(*args)

def is_binfile(*args):
  """
    is_binfile(binfile_name)->cue_name

    Determine if binfile_name is the BIN file part of a CDRWIN CD disk
    image.

    Return the corresponding CUE file if bin_name is a BIN file or
    None if not a BIN file.
    """
  return _pycdio.is_binfile(*args)

def is_cuefile(*args):
  """
    is_cuefile(cuefile_name)->bin_name

    Determine if cuefile_name is the CUE file part of a CDRWIN CD disk
    image.

    Return the corresponding BIN file if bin_name is a CUE file or
    None if not a CUE file.
    """
  return _pycdio.is_cuefile(*args)

def is_device(*args):
  """
    is_cuefile(cuefile_name)->bin_name

    Determine if cuefile_name is the CUE file part of a CDRWIN CD disk
    image.

    Return the corresponding BIN file if bin_name is a CUE file or
    None if not a CUE file.
    """
  return _pycdio.is_device(*args)

def is_nrg(*args):
  """
    is_nrg(cue_name)->bool

    Determine if nrg_name is a Nero CD disc image
    """
  return _pycdio.is_nrg(*args)

def is_tocfile(*args):
  """
    is_tocfile(tocfile_name)->bool

    Determine if tocfile_name is a cdrdao CD disc image
    """
  return _pycdio.is_tocfile(*args)

def get_media_changed(*args):
  """
    get_media_changed(cdio) -> int

    Find out if media has changed since the last call.
    Return 1 if media has changed since last call, 0 if not. Error
    return codes are the same as driver_return_code_t
    """
  return _pycdio.get_media_changed(*args)

def get_hwinfo(*args):
  """
    get_hwinfo(p_cdio)->[drc, vendor, model, release]
    Get the CD-ROM hardware info via a SCSI MMC INQUIRY command.
    """
  return _pycdio.get_hwinfo(*args)

def set_blocksize(*args):
  """
    set_blocksize(cdio, blocksize)->return_status

    Set the blocksize for subsequent reads.
    """
  return _pycdio.set_blocksize(*args)

def set_speed(*args):
  """
    cdio_set_speed(cdio, speed)->return_status
    Set the drive speed.
    """
  return _pycdio.set_speed(*args)

def open_cd(*args):
  """
    open_cd(source=NULL, driver_id=None, access_mode=None)

    Sets up to read from place specified by source, driver_id and
    access mode. This should be called before using any other routine
    except those that act on a CD-ROM drive by name. 

    If None is given as the source, we'll use the default driver device.
    If None is given as the driver_id, we'll find a suitable device driver.

    Return the a pointer than can be used in subsequent operations or 
    None on error or no device.
    """
  return _pycdio.open_cd(*args)

def set_python_errstring(*args):
  """
    open_cd(source=NULL, driver_id=None, access_mode=None)

    Sets up to read from place specified by source, driver_id and
    access mode. This should be called before using any other routine
    except those that act on a CD-ROM drive by name. 

    If None is given as the source, we'll use the default driver device.
    If None is given as the driver_id, we'll find a suitable device driver.

    Return the a pointer than can be used in subsequent operations or 
    None on error or no device.
    """
  return _pycdio.set_python_errstring(*args)
DISC_MODE_CD_DA = _pycdio.DISC_MODE_CD_DA
DISC_MODE_CD_DATA = _pycdio.DISC_MODE_CD_DATA
DISC_MODE_CD_XA = _pycdio.DISC_MODE_CD_XA
DISC_MODE_CD_MIXED = _pycdio.DISC_MODE_CD_MIXED
DISC_MODE_DVD_ROM = _pycdio.DISC_MODE_DVD_ROM
DISC_MODE_DVD_RAM = _pycdio.DISC_MODE_DVD_RAM
DISC_MODE_DVD_R = _pycdio.DISC_MODE_DVD_R
DISC_MODE_DVD_RW = _pycdio.DISC_MODE_DVD_RW
DISC_MODE_DVD_PR = _pycdio.DISC_MODE_DVD_PR
DISC_MODE_DVD_PRW = _pycdio.DISC_MODE_DVD_PRW
DISC_MODE_DVD_OTHER = _pycdio.DISC_MODE_DVD_OTHER
DISC_MODE_NO_INFO = _pycdio.DISC_MODE_NO_INFO
DISC_MODE_ERROR = _pycdio.DISC_MODE_ERROR
DISC_MODE_CD_I = _pycdio.DISC_MODE_CD_I

def get_disc_last_lsn(*args):
  """
    get_disc_last_lsn(cdio)->lsn
    Get the LSN of the end of the CD.

    pycdio.INVALID_LSN is returned on error.
    """
  return _pycdio.get_disc_last_lsn(*args)

def get_disc_mode(*args):
  """
    get_disc_mode(p_cdio) -> str

    Get disc mode - the kind of CD (CD-DA, CD-ROM mode 1, CD-MIXED, ...)
    that we've got. The notion of 'CD' is extended a little to include
    DVD's.
    """
  return _pycdio.get_disc_mode(*args)

def get_joliet_level(*args):
  """
    get_joliet_level(cdio)->int

    Return the Joliet level recognized for cdio.
    This only makes sense for something that has an ISO-9660
    filesystem.
    """
  return _pycdio.get_joliet_level(*args)

def get_mcn(*args):
  """
    get_mcn(cdio) -> str

    Get the media catalog number (MCN) from the CD.
    """
  return _pycdio.get_mcn(*args)

def get_num_tracks(*args):
  """
    get_num_tracks(p_cdio)->int

    Return the number of tracks on the CD. 
    On error pycdio.INVALID_TRACK is returned.
    """
  return _pycdio.get_num_tracks(*args)
INCLUDE_CLASS = _pycdio.INCLUDE_CLASS
# This file is compatible with both classic and new-style classes.


def get_drive_cap(*args):
  """
    get_drive_cap()->(read_cap, write_cap, misc_cap)

    Get drive capabilities of device.

    In some situations of drivers or OS's we can't find a CD device if
    there is no media in it. In this situation capabilities will show up as 
    empty even though there is a hardware CD-ROM.
    get_drive_cap_dev()->(read_cap, write_cap, misc_cap)

    Get drive capabilities of device.

    In some situations of drivers or OS's we can't find a CD device if
    there is no media in it. In this situation capabilities will show up as 
    empty even though there is a hardware CD-ROM.
    """
  return _pycdio.get_drive_cap(*args)
cvar = _pycdio.cvar




#!/usr/bin/env python
"""A program to show using iso9660 to extract a file from an ISO-9660
image.  If a single argument is given, it is used as the ISO 9660
image to use in the extraction. Otherwise a compiled in default ISO
9660 image name (that comes with the libcdio distribution) will be
used."""
#
#  Copyright (C) 2006, 2008, 2013 Rocky Bernstein <rocky@gnu.org>
#  
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <http://www.gnu.org/licenses/>.

import os, sys
libdir = os.path.join(os.path.dirname(__file__), '..')
if libdir[-1] != os.path.sep:
    libdir += os.path.sep
sys.path.insert(0, libdir)
import pycdio
import iso9660

PY3 = sys.version_info[0] == 3

# Python has rounding (round) and truncation (int), but what about an integer
# ceiling function? Until I learn what it is...
def ceil(x):
    return int(round(x+0.5))

# The default ISO 9660 image if none given
ISO9660_IMAGE_PATH="../data"
ISO9660_IMAGE=os.path.join(ISO9660_IMAGE_PATH, "copying.iso")

# File to extract if none given.
local_filename="copying"

iso_image_fname = ISO9660_IMAGE

if len(sys.argv) > 1:
    iso_image_fname = sys.argv[1]
    if len(sys.argv) > 2:
        local_filename = sys.argv[1]
        if len(sys.argv) > 3:
            print("""
usage: %s [ISO9660-image.ISO [filename]]
Extracts filename from ISO9660-image.ISO.
""" % sys.argv[0])
            sys.exit(1)

iso = iso9660.ISO9660.IFS(source=iso_image_fname)
  
if not iso.is_open():
    print("Sorry, couldn't open %s as an ISO-9660 image." % iso_image_fname)
    sys.exit(1)


statbuf = iso.stat (local_filename, True)

if statbuf is None:
    print("Could not get ISO-9660 file information for file %s" \
          % local_filename)
    iso.close()
    sys.exit(2)

try:
    OUTPUT=os.open(local_filename, os.O_CREAT|os.O_WRONLY, 0o664)
except:    
    print("Can't open %s for writing" % local_filename)

# Copy the blocks from the ISO-9660 filesystem to the local filesystem. 
blocks = ceil(statbuf['size'] / pycdio.ISO_BLOCKSIZE)
for i in range(blocks):
    lsn = statbuf['LSN'] + i
    size, buf = iso.seek_read (lsn)

    if size <= 0:
        print("Error reading ISO 9660 file %s at LSN %d" % (
            local_filename, lsn))
        sys.exit(4)
    
    if PY3:
        os.write(OUTPUT, bytes(buf, 'UTF-8'))
    else:
        os.write(OUTPUT, buf)
        pass

# Make sure the file size has the exact same byte size. Without the
# truncate below, the file will a multiple of ISO_BLOCKSIZE.

os.ftruncate(OUTPUT, statbuf['size'])

print("Extraction of file '%s' from %s successful." % (
    local_filename,  iso_image_fname))

os.close(OUTPUT)
iso.close()
sys.exit(0)



#!/usr/bin/env python
"""Program to show cdtext, similar to examples/cdtext.c"""
#
#  Copyright (C) 2006, 2008, 2009, 2012 Rocky Bernstein <rocky@gnu.org>
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <http://www.gnu.org/licenses/>.

import os, sys
libdir = os.path.join(os.path.dirname(__file__), '..')
if libdir[-1] != os.path.sep:
    libdir += os.path.sep
sys.path.insert(0, libdir)
import pycdio
import cdio

def print_cdtext_track_info_old(device, track, message):
    print(message)
    t = device.get_track(track)
    cdt = t.get_cdtext()

    for i in range(pycdio.MIN_CDTEXT_FIELDS, pycdio.MAX_CDTEXT_FIELDS):
        value = cdt.get(i)
        # value can be empty but exist, compared to NULL values
        if value is not None:
            print("\t%s: %s" % (pycdio.cdtext_field2str(i), value))
            pass
        pass
    return

def print_cdtext_info_new(device, message):
    print(message)
    cdt = device.get_cdtext()
    i_tracks = device.get_num_tracks()
    i_first_track = pycdio.get_first_track_num(device.cd)

    for t in range(i_first_track, i_tracks + i_first_track):
        for i in range(pycdio.MIN_CDTEXT_FIELD, pycdio.MAX_CDTEXT_FIELDS):
            value = cdt.get(i, t)
            # value can be empty but exist, compared to NULL values
            if value is not None:
                print("\t%s: %s" % (pycdio.cdtext_field2str(i), value))
                pass
            pass
        pass
    return

if sys.argv[1:]:
    try:
        drive_name = sys.argv[1]
        d = cdio.Device(sys.argv[1])
    except IOError:
        print("Problem opening CD-ROM: %s" % drive_name)
        sys.exit(1)
else:
    try:
        d = cdio.Device(driver_id=pycdio.DRIVER_UNKNOWN)
        drive_name = d.get_device()
    except IOError:
        print("Problem finding a CD-ROM")
        sys.exit(1)

if pycdio.VERSION_NUM < 83:
    i_tracks = d.get_num_tracks()
    i_first_track = pycdio.get_first_track_num(d.cd)
    print_cdtext_track_info_old(d, 0, 'CD-Text for Disc:')
    for i in range(i_first_track, i_tracks + i_first_track):
        print_cdtext_track_info_old(d, i, 'CD-Text for Track %d:' % i)
        pass
    pass
else:
    print_cdtext_info_new(d, 'CD-Text for disk')
    pass



#!/usr/bin/env python
"""A program to show CD information."""
#
#  Copyright (C) 2006, 2008, 2013 Rocky Bernstein <rocky@gnu.org>
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <http://www.gnu.org/licenses/>.

import os, sys
libdir = os.path.join(os.path.dirname(__file__), '..')
if libdir[-1] != os.path.sep:
    libdir += os.path.sep
sys.path.insert(0, libdir)
import pycdio
import cdio

if sys.argv[1:]:
    try:
        d = cdio.Device(sys.argv[1])
    except IOError:
        print("Problem opening CD-ROM: %s" % sys.argv[1])
        sys.exit(1)
else:
    try:
        d = cdio.Device(driver_id=pycdio.DRIVER_UNKNOWN)
    except IOError:
        print("Problem finding a CD-ROM")
        sys.exit(1)

t = d.get_first_track()
if t is None: 
    print("Problem getting first track")
    sys.exit(2)

first_track = t.track
num_tracks  = d.get_num_tracks()
last_track  = first_track+num_tracks-1

try:
    last_session = d.get_last_session()
    print("CD-ROM %s has %d track(s) and %d session(s)." % \
          (d.get_device(), d.get_num_tracks(), last_session))
except cdio.DriverUnsupportedError:
    print("CD-ROM %s has %d track(s). " % (d.get_device(), d.get_num_tracks()))

print("Track format is %s." %  d.get_disc_mode())

mcn = d.get_mcn()
if mcn:
    print("Media Catalog Number: %s" % mcn) 
    
print("%3s: %-6s  %s" % ("#", "LSN", "Format"))
i=first_track
while (i <= last_track):
    try: 
        t = d.get_track(i)
        print("%3d: %06lu  %-6s %s"  % (t.track, t.get_lsn(),
                                        t.get_msf(), t.get_format()))
    except cdio.TrackError:
        pass
    i += 1

print("%3X: %06lu  leadout" \
      % (pycdio.CDROM_LEADOUT_TRACK, d.get_disc_last_lsn()))

# check first track LSN
t = d.get_track(1)
lsn = t.get_lsn()
if lsn > 100:
    # cd-info simple heuristic, ideally use cdio_guess_cd_type
    print('\nHidden Track')  # see http://en.wikipedia.org/wiki/Hidden_Track


d.close()



#!/usr/bin/env python
"""Unit test for cdio

Note: for compatibility with old unittest 1.46 we won't use assertTrue
or assertFalse."""
import unittest, sys, os

libdir = os.path.join(os.path.dirname(__file__), '..')
if libdir[-1] != os.path.sep:
    libdir += os.path.sep
sys.path.insert(0, libdir)
import pycdio
import cdio

class CdioTests(unittest.TestCase):

    def test_ops(self):
        """Test running miscellaneous operations
        No assumption about the CD-ROM drives is made, so
        we're just going to run operations and see that they
        don't crash."""
        self.device = cdio.Device()
        if pycdio.VERSION_NUM >= 76:
            # FIXME: Broken on Darwin? 
            # self.device.open()
            self.device.have_ATAPI()
            # FIXME: Broken on Darwin? 
            # self.device.get_media_changed()
        self.assertEqual(True, True, "Test misc operations")
        return

    def test_device_default(self):
        """Test getting default device"""
        result1=cdio.get_default_device_driver(pycdio.DRIVER_DEVICE)
        result2=cdio.get_default_device_driver()
        self.assertEqual(result1, result2,
                         "get_default_device with/out parameters")
        self.device = cdio.Device()
        result2=pycdio.get_device()
        if result1 is not None:
            self.assertEqual(result1[0], result2)
            # Now try getting device using driver that we got back
            try: 
              device=cdio.Device(driver_id=result1[1])
              result1 = device.get_device()
              self.assertEqual(result1, result2,
                             "get_default_device using driver name")
            except:
              pass
        return

    def test_exceptions(self):
        """Test that various routines raise proper exceptions"""
        self.device = cdio.Device()
        # No CD or or CD image has been set yet. So these fail
        try: 
          lsn = self.device.get_disc_last_lsn()
        except IOError:
          self.assertEqual(True, True, "get_last_lsn() IO Error")
        except cdio.DriverError:
          self.assertEqual(True, True, "get_last_lsn() DriverError")
        else:
           self.assertTrue(False, "get_last_lsn() should raise error")
        self.assertRaises(IOError, self.device.get_disc_mode)
        try:
          track = self.device.get_num_tracks()
        except IOError:
          self.assertEqual(True, True, "get_num_tracks() IO Error")
        except cdio.DriverError:
          self.assertEqual(True, True, "get_num_tracks() DriverError")
        except cdio.TrackError:
          self.assertEqual(True, True, "get_num_tracks() TrackError")
        else:
           self.assertTrue(False, "get_last_lsn() should raise error")
        self.assertRaises(IOError, self.device.get_driver_name)
        self.assertRaises(cdio.DriverUninitError,
                          self.device.get_media_changed)
        self.assertRaises(IOError, self.device.open, "***Invalid device***")
        return

    def test_have_image_drivers(self):
        """Test that we have image drivers"""
        result = cdio.have_driver('CDRDAO')
        self.assertEqual(True, result, "Have cdrdrao driver via string")
        result = cdio.have_driver(pycdio.DRIVER_CDRDAO)
        self.assertEqual(True, result, "Have cdrdrao driver via driver_id")
        result = cdio.have_driver('NRG')
        self.assertEqual(True, result, "Have NRG driver via string")
        result = cdio.have_driver(pycdio.DRIVER_NRG)
        self.assertEqual(True, result, "Have NRG driver via driver_id")
        result = cdio.have_driver('BIN/CUE')
        self.assertEqual(True, result, "Have BIN/CUE driver via string")
        result = cdio.have_driver(pycdio.DRIVER_BINCUE)
        self.assertEqual(True, result, "Have BIN/CUE driver via driver_id")
        return

    def test_tocfile(self):
        """Test functioning of cdrdao image routines"""
        ## TOC reading needs to be done in the directory where the
        ## TOC/BIN files reside.
        olddir=os.getcwd()
        os.chdir('.')
        tocfile="cdda.toc"
        device = cdio.Device(tocfile, pycdio.DRIVER_CDRDAO)
        ok, vendor, model, revision  = device.get_hwinfo()
        self.assertEqual(True, ok, "get_hwinfo ok")
        self.assertEqual('libcdio', vendor, "get_hwinfo vendor")
        self.assertEqual('cdrdao', model, "get_hwinfo cdrdao")
        # Test known values of various access parameters:
        # access mode, driver name via string and via driver_id
        # and cue name
        result = device.get_arg("access-mode")
        self.assertEqual(result, 'image', 'get_arg("access_mode")',)
        result = device.get_driver_name()
        self.assertEqual(result, 'CDRDAO', 'get_driver_name')
        result = device.get_driver_id()
        self.assertEqual(result, pycdio.DRIVER_CDRDAO, 'get_driver_id')
        result = device.get_arg("source")
        self.assertEqual(result, tocfile, 'get_arg("source")')
        result = device.get_media_changed()
        self.assertEqual(False, result, "tocfile: get_media_changed")
        # Test getting is_tocfile
        result = cdio.is_tocfile(tocfile)
        self.assertEqual(True, result, "is_tocfile(tocfile)")
        result = cdio.is_nrg(tocfile)
        self.assertEqual(False, result, "is_nrgfile(tocfile)")
        result = cdio.is_device(tocfile)
        self.assertEqual(False, result, "is_device(tocfile)")
        self.assertRaises(cdio.DriverUnsupportedError,
                          device.set_blocksize, 2048)
        self.assertRaises(cdio.DriverUnsupportedError,
                          device.set_speed, 5)
        device.close()
        os.chdir(olddir)
        return

    def test_read(self):
        """Test functioning of read routines"""
        cuefile="./../data/isofs-m1.cue"
        device = cdio.Device(source=cuefile)
        # Read the ISO Primary Volume descriptor
        blocks, data=device.read_sectors(16, pycdio.READ_MODE_M1F1)
        self.assertEqual(data[1:6], 'CD001')
        self.assertEqual(blocks, 1)
        blocks, data=device.read_data_blocks(26)
        self.assertEqual(data[6:32], 'GNU GENERAL PUBLIC LICENSE')
        return

    def test_bincue(self):
        """Test functioning of BIN/CUE image routines"""
        cuefile="./cdda.cue"
        device = cdio.Device(source=cuefile)
        # Test known values of various access parameters:
        # access mode, driver name via string and via driver_id
        # and cue name
        result = device.get_arg("access-mode")
        self.assertEqual(result, 'image', 'get_arg("access_mode")',)
        result = device.get_driver_name()
        self.assertEqual(result, 'BIN/CUE', 'get_driver_name')
        result = device.get_driver_id()
        self.assertEqual(result, pycdio.DRIVER_BINCUE, 'get_driver_id')
        result = device.get_arg("cue")
        self.assertEqual(result, cuefile, 'get_arg("cue")')
        # Test getting is_binfile and is_cuefile
        binfile = cdio.is_cuefile(cuefile)
        self.assertEqual(True, binfile != None, "is_cuefile(cuefile)")
        cuefile2 = cdio.is_binfile(binfile)
        # Could check that cuefile2 == cuefile, but some OS's may 
        # change the case of files
        self.assertEqual(True, cuefile2 != None, "is_cuefile(binfile)")
        result = cdio.is_tocfile(cuefile)
        self.assertEqual(False, result, "is_tocfile(tocfile)")
        ok, vendor, model, revision  = device.get_hwinfo()
        self.assertEqual(True, ok, "get_hwinfo ok")
        self.assertEqual('libcdio', vendor, "get_hwinfo vendor")
        self.assertEqual('CDRWIN', model, "get_hwinfo model")
        result = cdio.is_device(cuefile)
        self.assertEqual(False, result, "is_device(tocfile)")
        result = device.get_media_changed()
        self.assertEqual(False, result, "binfile: get_media_changed")
        if pycdio.VERSION_NUM >= 77:
            # There's a bug in libcdio 0.76 that causes these to crash
            self.assertRaises(cdio.DriverUnsupportedError,
                              device.set_blocksize, 2048)
            self.assertRaises(cdio.DriverUnsupportedError,
                              device.set_speed, 5)
        device.close()
        return

    def test_cdda(self):
        """Test functioning CD-DA"""
        device = cdio.Device()
        cuefile="./cdda.cue"
        device.open(cuefile)
        result = device.get_disc_mode()
        self.assertEqual(result, 'CD-DA', 'get_disc_mode')
        self.assertEqual(device.get_mcn(), '0000010271955', 'get_mcn')
        self.assertRaises(cdio.DriverUnsupportedError,
                          device.get_last_session)
        # self.assertRaises(IOError, device.get_joliet_level)
        result = device.get_num_tracks()
        self.assertEqual(result, 1, 'get_num_tracks')
        disc_last_lsn = device.get_disc_last_lsn()
        self.assertEqual(disc_last_lsn, 302, 'get_disc_last_lsn')
        t=device.get_last_track()
        self.assertEqual(t.track, 1, 'get_last_track')
        self.assertEqual(t.get_last_lsn(), 301, '(track) get_last_lsn')
        self.assertEqual(device.get_track_for_lsn(t.get_last_lsn()).track,
                         t.track)
        t=device.get_first_track()
        self.assertEqual(t.track, 1, 'get_first_track')
        self.assertEqual(t.get_format(), 'audio', 'get_track_format')
        device.close()
        return
    
if __name__ == "__main__":
    unittest.main()



#  Copyright (C) 2006, 2008, 2010, 2013 Rocky Bernstein <rocky@gnu.org>
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <http://www.gnu.org/licenses/>.

import pycdio
import pyiso9660
import cdio
import types

check_types = {
    'nocheck'   : pyiso9660.NOCHECK,
    '7bit'      : pyiso9660.SEVEN_BIT,
    'achars'    : pyiso9660.ACHARS,
    'dchars'    : pyiso9660.DCHARS
    }

def dirname_valid_p(path):
    """dirname_valid_p(path)->bool

Check that path is a valid ISO-9660 directory name.

A valid directory name should not start out with a slash (/), 
dot (.) or null byte, should be less than 37 characters long, 
have no more than 8 characters in a directory component 
which is separated by a /, and consist of only DCHARs. 

True is returned if path is valid."""
    return pyiso9660.dirname_valid(path)


def is_achar(achar):
    """is_achar(achar)->bool

Return 1 if achar is an ACHAR. achar should either be a string of 
length one or the ord() of a string of length 1.

These are the DCHAR's plus some ASCII symbols including the space 
symbol."""   
    if type(achar) != int:
	# Not integer. Should be a string of length one then.
        # We'll turn it into an integer.
        try:
            achar = ord(achar)
        except:
            return 0 
    else:
	# Is an integer. Is it too large?
        if achar > 255: return 0 
    return pyiso9660.is_achar(achar)


def is_dchar(dchar):
    """is_dchar(dchar)->bool

Return 1 if dchar is a DCHAR - a character that can appear in an an
ISO-9600 level 1 directory name. These are the ASCII capital
letters A-Z, the digits 0-9 and an underscore.

dchar should either be a string of length one or the ord() of a string
of length 1."""

    if type(dchar) != int:
	# Not integer. Should be a string of length one then.
        # We'll turn it into an integer.
        try:
            dchar = ord(dchar)
        except:
            return 0 
    else:
	# Is an integer. Is it too large?
        if dchar > 255: return 0 
    return pyiso9660.is_dchar(dchar)


def pathname_valid_p(path):
    """pathname_valid_p(path)->bool

Check that path is a valid ISO-9660 pathname.  

A valid pathname contains a valid directory name, if one appears and
the filename portion should be no more than 8 characters for the
file prefix and 3 characters in the extension (or portion after a
dot). There should be exactly one dot somewhere in the filename
portion and the filename should be composed of only DCHARs.
  
True is returned if path is valid."""
    return pyiso9660.pathame_valid(path)


def pathname_isofy(path, version=1):
    """pathname_valid_p(path, version=1)->string

Take path and a version number and turn that into a ISO-9660 pathname.
(That's just the pathname followed by ';' and the version number. For
example, mydir/file.ext -> MYDIR/FILE.EXT;1 for version 1. The
resulting ISO-9660 pathname is returned."""
    return pyiso9660.pathname_isofy(path, version)

def name_translate(filename, joliet_level=0):
    """name_translate(name, joliet_level=0)->str

Convert an ISO-9660 file name of the kind that is that stored in a ISO
9660 directory entry into what's usually listed as the file name in a
listing.  Lowercase name if no Joliet Extension interpretation. Remove
trailing ;1's or .;1's and turn the other ;'s into version numbers.

If joliet_level is not given it is 0 which means use no Joliet
Extensions. Otherwise use the specified the Joliet level. 

The translated string is returned and it will be larger than the input
filename."""
    return pyiso9660.name_translate_ext(filename, joliet_level)


# FIXME: should be
# def stat_array_to_dict(*args):
# Probably have a SWIG error.
def stat_array_to_dict(filename, LSN, size, sec_size, is_dir):
    """stat_array_to_dict(filename, LSN, size, sec_size, is_dir)->stat

Convert a ISO 9660 array to an hash reference of the values.

Used internally in convert from C code."""

    stat = {}
    stat['filename'] = filename
    stat['LSN']      = LSN
    stat['size']     = size
    stat['sec_size'] = sec_size
    stat['is_dir']   = is_dir == 2
    return stat
 
def strncpy_pad(name, len, check):
    """strncpy_pad(src, len, check='nocheck')->str

Pad string 'name' with spaces to size len and return this. If 'len' is
less than the length of 'src', the return value will be truncated to
the first len characters of 'name'.

'name' can also be scanned to see if it contains only ACHARs, DCHARs,
or 7-bit ASCII chars, and this is specified via the 'check' parameter. 
If the I<check> parameter is given it must be one of the 'nocheck',
'7bit', 'achars' or 'dchars'. Case is not significant."""
    if check not in check_types:
        print("*** A CHECK parameter must be one of %s\n" % \
              ', '.join(list(check_types.keys())))
        return None
    return pyiso9660.strncpy_pad(name, len, check_types[check])

class ISO9660:
    """ """
    class IFS:
        """ISO 9660 Filesystem image reading"""

        def __init__(self, source=None, iso_mask=pyiso9660.EXTENSION_NONE):

            """Create a new ISO 9660 object.  If source is given, open()
            is called using that and the optional iso_mask parameter;
            iso_mask is used only if source is specified.  If source is
            given but opening fails, undef is returned.  If source is not
            given, an object is always returned."""
            
            self.iso9660 = None
            if source is not None:
                self.open(source, iso_mask)

        def close(self):
            """close(self)->bool
                    
            Close previously opened ISO 9660 image and free resources
            associated with ISO9660.  Call this when done using using
            an ISO 9660 image."""
            
            if self.iso9660 is not None:
                pyiso9660.close(self.iso9660)
            else:
                print("***No object to close")
            self.iso9660 = None

        def find_lsn(self, lsn):
            """find_lsn(self, lsn)->[stat_href]

            Find the filesystem entry that contains LSN and return
            file stat information about it. None is returned on
            error."""

            if pycdio.VERSION_NUM <= 76:
                print("*** Routine available only in libcdio versions >= 0.76")
                return None
            
            filename, LSN, size, sec_size, is_dir = \
                      pyiso9660.ifs_find_lsn(self.iso9660, lsn)
            return stat_array_to_dict(filename, LSN, size, sec_size, is_dir)
    

        def get_application_id(self):
            """get_application_id(self)->id
            
            Get the application ID stored in the Primary Volume Descriptor.
            None is returned if there is some problem."""
            
            return pyiso9660.ifs_get_application_id(self.iso9660)

        def get_preparer_id(self):
            """get_preparer_id(self)->id
            
            Get the preparer ID stored in the Primary Volume Descriptor.
            None is returned if there is some problem."""
            
            return pyiso9660.ifs_get_preparer_id(self.iso9660)


        def get_publisher_id(self):
            """get_publisher_id()->id
            
            Get the publisher ID stored in the Primary Volume Descriptor.
            undef is returned if there is some problem."""
            return pyiso9660.ifs_get_publisher_id(self.iso9660)
    
        def get_root_lsn(self):
            """get_root_lsn(self)->lsn
            
            Get the Root LSN stored in the Primary Volume Descriptor.
            undef is returned if there is some problem."""
            
            return pyiso9660.ifs_get_root_lsn(self.iso9660)
        
        def get_system_id(self):
            """get_system_id(self)->id
            
            Get the Volume ID stored in the Primary Volume Descriptor.
            undef is returned if there is some problem."""
            
            return pyiso9660.ifs_get_system_id(self.iso9660)

        def get_volume_id(self):
            """get_volume_id()->id
            
            Get the Volume ID stored in the Primary Volume Descriptor.
            undef is returned if there is some problem."""
            
            return pyiso9660.ifs_get_volume_id(self.iso9660)

        def get_volumeset_id(self):
            """get_volume_id(self)->id
            
            Get the Volume ID stored in the Primary Volume Descriptor.
            undef is returned if there is some problem."""
            
            return pyiso9660.ifs_get_volumeset_id(self.iso9660)
        
        def is_open(self):
            """is_open(self)->bool
            Return true if we have an ISO9660 image open.
            """
            return self.iso9660 is not None

        def open(self, source, iso_mask=pyiso9660.EXTENSION_NONE):
            """open(source, iso_mask=pyiso9660.EXTENSION_NONE)->bool
            
            Open an ISO 9660 image for reading. Subsequent operations
            will read from this ISO 9660 image.
            
            This should be called before using any other routine
            except possibly new. It is implicitly called when a new is
            done specifying a source.
            
            If device object was previously opened it is closed first.
            
            See also open_fuzzy."""
            
            if self.iso9660 is not None: self.close() 

            self.iso9660 = pyiso9660.open_ext(source, iso_mask)
            return self.iso9660 is not None


        def open_fuzzy(self, source, iso_mask=pyiso9660.EXTENSION_NONE,
                       fuzz=20):
            """open_fuzzy(source, iso_mask=pyiso9660.EXTENSION_NONE,
                          fuzz=20)->bool
            
            Open an ISO 9660 image for reading. Subsequent operations
            will read from this ISO 9660 image. Some tolerence allowed
            for positioning the ISO9660 image. We scan for
            pyiso9660.STANDARD_ID and use that to set the eventual
            offset to adjust by (as long as that is <= fuzz).
            
            This should be called before using any other routine
            except possibly new (which must be called first. It is
            implicitly called when a new is done specifying a source.
            
            See also open."""

            if self.iso9660 is not None: self.close() 
            
            if type(fuzz) != int:
                print("*** Expecting fuzz to be an integer; got 'fuzz'")
                return False
            
            self.iso9660 = pyiso9660.open_fuzzy_ext(source, iso_mask, fuzz)
            return self.iso9660 is not None
        
        def read_fuzzy_superblock(self, iso_mask=pyiso9660.EXTENSION_NONE,
                                  fuzz=20):
            """read_fuzzy_superblock(iso_mask=pyiso9660.EXTENSION_NONE,
                                     fuzz=20)->bool
            
            Read the Super block of an ISO 9660 image but determine
            framesize and datastart and a possible additional
            offset. Generally here we are not reading an ISO 9660 image
            but a CD-Image which contains an ISO 9660 filesystem."""
            
            if type(fuzz) != int:
                print("*** Expecting fuzz to be an integer; got 'fuzz'")
                return False
            
            return pyiso9660.ifs_fuzzy_read_superblock(self.iso9660, iso_mask,
                                                       fuzz)
        
        def readdir(self, dirname): 
            """readdir(dirname)->[LSN, size, sec_size, filename, XA, is_dir]
            
            Read path (a directory) and return a list of iso9660 stat
            references
            
            Each item of @iso_stat is a hash reference which contains

            * LSN       - the Logical sector number (an integer)
            * size      - the total size of the file in bytes
            * sec_size  - the number of sectors allocated
            * filename  - the file name of the statbuf entry
            * XA        - if the file has XA attributes; 0 if not
            * is_dir    - 1 if a directory; 0 if a not;
            
            FIXME: If you look at iso9660.h you'll see more fields, such as for
            Rock-Ridge specific fields or XA specific fields. Eventually these
            will be added. Volunteers?"""
            
            return pyiso9660.ifs_readdir(self.iso9660, dirname)


        def read_pvd(self):
            """read_pvd()->pvd
            
            Read the Super block of an ISO 9660 image. This is the
            Primary Volume Descriptor (PVD) and perhaps a Supplemental
            Volume Descriptor if (Joliet) extensions are
            acceptable."""
            
            return pyiso9660.ifs_read_pvd(self.iso9660)

        def read_superblock(self, iso_mask=pyiso9660.EXTENSION_NONE):
            """read_superblock(iso_mask=pyiso9660.EXTENSION_NONE)->bool
            
            Read the Super block of an ISO 9660 image. This is the
            Primary Volume Descriptor (PVD) and perhaps a Supplemental
            Volume Descriptor if (Joliet) extensions are
            acceptable."""
            
            return pyiso9660.ifs_read_superblock(self.iso9660, iso_mask)

        def seek_read(self, start, size=1):
            """seek_read(self, start, size=1)
            ->(size, str)
            
            Seek to a position and then read n blocks. A block is
            pycdio.ISO_BLOCKSIZE (2048) bytes. The Size in BYTES (not blocks)
            is returned."""
            size *= pyiso9660.ISO_BLOCKSIZE
            return pyiso9660.seek_read(self.iso9660, start, size)

        def stat(self, path, translate=False):
            """stat(self, path, translate=False)->{stat}
            
            Return file status for path name path. None is returned on
            error.  If translate is True, version numbers in the ISO 9660
            name are dropped, i.e. ;1 is removed and if level 1 ISO-9660
            names are lowercased.
            
            Each item of the return is a hash reference which contains:
            
            * LSN      - the Logical sector number (an integer)
            * size     - the total size of the file in bytes
            * sec_size - the number of sectors allocated
            * filename - the file name of the statbuf entry
            * XA       - if the file has XA attributes; False if not
            * is_dir   - True if a directory; False if a not."""
            
            if translate:
                values = pyiso9660.ifs_stat_translate(self.iso9660, path)
            else:
                values = pyiso9660.ifs_stat(self.iso9660, path)
            return stat_array_to_dict(values[0], values[1], values[2],
                                      values[3], values[4])

    class FS(cdio.Device):
        """ISO 9660 CD reading"""

        def __init__(self, source=None, driver_id=None,
                     access_mode=None):

            """Create a new ISO 9660 object.  If source is given, open()
            is called using that and the optional iso_mask parameter;
            iso_mask is used only if source is specified.  If source is
            given but opening fails, undef is returned.  If source is not
            given, an object is always returned."""
            
            cdio.Device.__init__(self, source, driver_id, access_mode)


        def find_lsn(self, lsn):
            """find_lsn(self, lsn)->[stat_href]

            Find the filesystem entry that contains LSN and return
            file stat information about it. None is returned on
            error."""

            filename, LSN, size, sec_size, is_dir = \
                      pyiso9660.fs_find_lsn(self.cd, lsn)
            return stat_array_to_dict(filename, LSN, size, sec_size, is_dir)
    
        
        def readdir(self, dirname): 
            """readdir(dirname)->[LSN, size, sec_size, filename, XA, is_dir]
            
            Read path (a directory) and return a list of iso9660 stat
            references
            
            Each item of @iso_stat is a hash reference which contains

            * LSN       - the Logical sector number (an integer)
            * size      - the total size of the file in bytes
            * sec_size  - the number of sectors allocated
            * filename  - the file name of the statbuf entry
            * XA        - if the file has XA attributes; 0 if not
            * is_dir    - 1 if a directory; 0 if a not;
            
            FIXME: If you look at iso9660.h you'll see more fields, such as for
            Rock-Ridge specific fields or XA specific fields. Eventually these
            will be added. Volunteers?"""
            
            return pyiso9660.fs_readdir(self.cd, dirname)


        def read_pvd(self):
            """read_pvd()->pvd
            
            Read the Super block of an ISO 9660 image. This is the
            Primary Volume Descriptor (PVD) and perhaps a Supplemental
            Volume Descriptor if (Joliet) extensions are
            acceptable."""
            
            return pyiso9660.fs_read_pvd(self.cd)

        def read_superblock(self, iso_mask=pyiso9660.EXTENSION_NONE):
            """read_superblock(iso_mask=pyiso9660.EXTENSION_NONE)->bool
            
            Read the Super block of an ISO 9660 image. This is the
            Primary Volume Descriptor (PVD) and perhaps a Supplemental
            Volume Descriptor if (Joliet) extensions are
            acceptable."""
            
            return pyiso9660.fs_read_superblock(self.cd, iso_mask)

        def stat(self, path, translate=False):
            """stat(self, path, translate=False)->{stat}
            
            Return file status for path name path. None is returned on
            error.  If translate is True, version numbers in the ISO 9660
            name are dropped, i.e. ;1 is removed and if level 1 ISO-9660
            names are lowercased.
            
            Each item of the return is a hash reference which contains:
            
            * LSN      - the Logical sector number (an integer)
            * size     - the total size of the file in bytes
            * sec_size - the number of sectors allocated
            * filename - the file name of the statbuf entry
            * XA       - if the file has XA attributes; False if not
            * is_dir   - True if a directory; False if a not."""
            
            if translate:
                values = pyiso9660.fs_stat_translate(self.cd, path)
            else:
                values = pyiso9660.fs_stat(self.cd, path)
                pass
            if values:
                return stat_array_to_dict(values[0], values[1], values[2],
                                          values[3], values[4])
            else:
                return None
            pass
        pass
    pass



#!/usr/bin/env python
"""Program to read CD blocks. See read-cd from the libcdio distribution
for a more complete program.
"""
#
#  Copyright (C) 2006, 2008, 2010, 2013 Rocky Bernstein <rocky@gnu.org>
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <http://www.gnu.org/licenses/>.

import sys, os
from optparse import OptionParser

libdir = os.path.join(os.path.dirname(__file__), '..')
if libdir[-1] != os.path.sep:
    libdir += os.path.sep
sys.path.insert(0, libdir)
import pycdio
import cdio

read_modes = {
    'audio': pycdio.READ_MODE_AUDIO,
    'm1f1' : pycdio.READ_MODE_M1F1,
    'm1f2' : pycdio.READ_MODE_M1F2,
    'm2f1' : pycdio.READ_MODE_M2F1,
    'm2f2' : pycdio.READ_MODE_M2F2,
    'data' : None
    }

def process_options():
    program = os.path.basename(sys.argv[0])
    usage_str="""%s --mode *mode* [options] [device]
    Read blocks of a CD""" % program

    optparser = OptionParser(usage=usage_str)

    optparser.add_option("-m", "--mode", dest="mode",
                         action="store", type='string',	
                         help="CD Reading mode: audio, m1f1, m1f2, " + 
	 	              "m2f1 or m2f2")
    optparser.add_option("-s", "--start", dest="start",
                         action="store", type='int', default=1,
                         help="Starting block")
    optparser.add_option("-n", "--number", dest="number",
                         action="store", type='int', default=1,
                         help="Number of blocks")
    (opts, argv) = optparser.parse_args()
    if opts.mode is None:
        print("Mode option must given via --mode " + \
              "and one of: audio, m1f1, m1f2, m1f2 or m1f2.")
        sys.exit(1)
    try:
        read_mode = read_modes[opts.mode]
    except KeyError:
        print("Need to use the --mode option with one of" + \
              "audio, m1f1, m1f2, m1f2 or m1f2")
        sys.exit(2)
        
    return opts, argv, read_mode

import re
PRINTABLE = r'[ -~]'
pat = re.compile(PRINTABLE)
def isprint(c):
    global pat
    return pat.match(c)

def hexdump (buffer, just_hex=False):
    i = 0
    s = ''
    while i < len(buffer):
        if (i % 16) == 0:
            s += ("0x%04x: " % i)
            pass
        s += ("%02x%02x " % (ord(buffer[i]), ord(buffer[i+1])))
        if (i % 16) == 14:
            if not just_hex:
                s += "  "
                for j in range(i-14, i+2):
                    if isprint(buffer[j]):
                        s += buffer[j]
                    else:
                        s += '.'
                        pass
                pass
            print(s)
            s = ''
        i += 2
        pass
    print('')
    return

opts, argv, read_mode = process_options()
# While sys.argv[0] is a program name and sys.argv[1] the first
# option, argv[0] is the first unprocessed option -- roughly
# the equivalent of sys.argv[1].
if argv[0:]:
    try:
        d = cdio.Device(argv[0])
    except IOError:
        print("Problem opening CD-ROM: %s" % argv[0])
        sys.exit(1)
else:
    try:
        d = cdio.Device(driver_id=pycdio.DRIVER_UNKNOWN)
    except IOError:
        print("Problem finding a CD-ROM")
        sys.exit(1)

## All this setup just to issue this one of these commands.
if read_mode == None:
    blocks, data=d.read_data_blocks(opts.start, opts.number)
else:
    blocks, data=d.read_sectors(opts.start, read_mode, opts.number)
hexdump(data)




#!/usr/bin/env python
"""Unit test for cdtext."""

import unittest, sys, os

libdir = os.path.join(os.path.dirname(__file__), '..')
if libdir[-1] != os.path.sep:
    libdir += os.path.sep
sys.path.insert(0, libdir)
import pycdio
import cdio

class CDTextTests(unittest.TestCase):

    def test_keyword(self):
        """Test keywords"""
        if pycdio.VERSION_NUM > 83:
            self.assertEquals(pycdio.cdtext_field2str(
                pycdio.CDTEXT_FIELD_PERFORMER), "PERFORMER")
        else:
            self.assertEquals(pycdio.cdtext_field2str(pycdio.CDTEXT_PERFORMER),
                "PERFORMER")

    def test_get_set(self):
        """Test getting and setting CDText"""
        tocpath = os.path.join(os.path.dirname(__file__),
            "cdtext.toc")
        device = cdio.Device(tocpath, pycdio.DRIVER_CDRDAO)

        if pycdio.VERSION_NUM > 83:
            text = device.get_cdtext()
            self.assertEquals(text.get(pycdio.CDTEXT_FIELD_PERFORMER, 0), 'Performer')
            self.assertEquals(text.get(pycdio.CDTEXT_FIELD_TITLE, 0), 'CD Title')
            self.assertEquals(text.get(pycdio.CDTEXT_FIELD_DISCID, 0), 'XY12345')

            self.assertEquals(text.get(pycdio.CDTEXT_FIELD_PERFORMER, 1), 'Performer')
            self.assertEquals(text.get(pycdio.CDTEXT_FIELD_TITLE, 1), 'Track Title')

        else:
            disctext = device.get_track(0).get_cdtext()
            self.assertEquals(disctext.get(pycdio.CDTEXT_PERFORMER), 'Performer')
            self.assertEquals(disctext.get(pycdio.CDTEXT_TITLE), 'CD Title')
            self.assertEquals(disctext.get(pycdio.CDTEXT_DISCID), 'XY12345')

            track1text = device.get_track(1).get_cdtext()
            self.assertEquals(track1text.get(pycdio.CDTEXT_PERFORMER), 'Performer')
            self.assertEquals(track1text.get(pycdio.CDTEXT_TITLE), 'Track Title')

            track1text.set(pycdio.CDTEXT_PERFORMER, 'Someone')
            self.assertEquals(track1text.get(pycdio.CDTEXT_PERFORMER), 'Someone')

if __name__ == "__main__":
    unittest.main()



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 2.0.4
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.


"""
This is a wrapper for The CD Input and Control library's ISO-9660 library
See also the ISO-9660 specification. The freely available European
equivalant standard is called ECMA-119.
"""


from sys import version_info
if version_info >= (2,6,0):
    def swig_import_helper():
        from os.path import dirname
        import imp
        fp = None
        try:
            fp, pathname, description = imp.find_module('_pyiso9660', [dirname(__file__)])
        except ImportError:
            import _pyiso9660
            return _pyiso9660
        if fp is not None:
            try:
                _mod = imp.load_module('_pyiso9660', fp, pathname, description)
            finally:
                fp.close()
            return _mod
    _pyiso9660 = swig_import_helper()
    del swig_import_helper
else:
    import _pyiso9660
del version_info
try:
    _swig_property = property
except NameError:
    pass # Python < 2.2 doesn't have 'property'.
def _swig_setattr_nondynamic(self,class_type,name,value,static=1):
    if (name == "thisown"): return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name,None)
    if method: return method(self,value)
    if (not static):
        self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)

def _swig_setattr(self,class_type,name,value):
    return _swig_setattr_nondynamic(self,class_type,name,value,0)

def _swig_getattr(self,class_type,name):
    if (name == "thisown"): return self.this.own()
    method = class_type.__swig_getmethods__.get(name,None)
    if method: return method(self)
    raise AttributeError(name)

def _swig_repr(self):
    try: strthis = "proxy of " + self.this.__repr__()
    except: strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except AttributeError:
    class _object : pass
    _newclass = 0


class imaxdiv_t(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, imaxdiv_t, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, imaxdiv_t, name)
    __repr__ = _swig_repr
    __swig_setmethods__["quot"] = _pyiso9660.imaxdiv_t_quot_set
    __swig_getmethods__["quot"] = _pyiso9660.imaxdiv_t_quot_get
    if _newclass:quot = _swig_property(_pyiso9660.imaxdiv_t_quot_get, _pyiso9660.imaxdiv_t_quot_set)
    __swig_setmethods__["rem"] = _pyiso9660.imaxdiv_t_rem_set
    __swig_getmethods__["rem"] = _pyiso9660.imaxdiv_t_rem_get
    if _newclass:rem = _swig_property(_pyiso9660.imaxdiv_t_rem_get, _pyiso9660.imaxdiv_t_rem_set)
    def __init__(self): 
        """Return true if ISO 9660 image has extended attrributes (XA)."""
        this = _pyiso9660.new_imaxdiv_t()
        try: self.this.append(this)
        except: self.this = this
    __swig_destroy__ = _pyiso9660.delete_imaxdiv_t
    __del__ = lambda self : None;
imaxdiv_t_swigregister = _pyiso9660.imaxdiv_t_swigregister
imaxdiv_t_swigregister(imaxdiv_t)


def imaxabs(*args):
  return _pyiso9660.imaxabs(*args)
imaxabs = _pyiso9660.imaxabs

def imaxdiv(*args):
  return _pyiso9660.imaxdiv(*args)
imaxdiv = _pyiso9660.imaxdiv

def strtoimax(*args):
  return _pyiso9660.strtoimax(*args)
strtoimax = _pyiso9660.strtoimax

def strtoumax(*args):
  return _pyiso9660.strtoumax(*args)
strtoumax = _pyiso9660.strtoumax

def wcstoimax(*args):
  return _pyiso9660.wcstoimax(*args)
wcstoimax = _pyiso9660.wcstoimax

def wcstoumax(*args):
  return _pyiso9660.wcstoumax(*args)
wcstoumax = _pyiso9660.wcstoumax
VERSION_NUM = _pyiso9660.VERSION_NUM
INVALID_LBA = _pyiso9660.INVALID_LBA
INVALID_LSN = _pyiso9660.INVALID_LSN
CD_FRAMESIZE = _pyiso9660.CD_FRAMESIZE
CD_FRAMESIZE_RAW = _pyiso9660.CD_FRAMESIZE_RAW
ISO_BLOCKSIZE = _pyiso9660.ISO_BLOCKSIZE
M2F2_SECTOR_SIZE = _pyiso9660.M2F2_SECTOR_SIZE
M2RAW_SECTOR_SIZE = _pyiso9660.M2RAW_SECTOR_SIZE
PVD_SECTOR = _pyiso9660.PVD_SECTOR
EVD_SECTOR = _pyiso9660.EVD_SECTOR
LEN_ISONAME = _pyiso9660.LEN_ISONAME
MAX_SYSTEM_ID = _pyiso9660.MAX_SYSTEM_ID
MAX_ISONAME = _pyiso9660.MAX_ISONAME
MAX_PREPARER_ID = _pyiso9660.MAX_PREPARER_ID
MAX_ISOPATHNAME = _pyiso9660.MAX_ISOPATHNAME
FILE = _pyiso9660.FILE
EXISTENCE = _pyiso9660.EXISTENCE
DIRECTORY = _pyiso9660.DIRECTORY
ASSOCIATED = _pyiso9660.ASSOCIATED
RECORD = _pyiso9660.RECORD
PROTECTION = _pyiso9660.PROTECTION
DRESERVED1 = _pyiso9660.DRESERVED1
DRESERVED2 = _pyiso9660.DRESERVED2
MULTIEXTENT = _pyiso9660.MULTIEXTENT
VD_BOOT_RECORD = _pyiso9660.VD_BOOT_RECORD
VD_PRIMARY = _pyiso9660.VD_PRIMARY
VD_SUPPLEMENTARY = _pyiso9660.VD_SUPPLEMENTARY
VD_PARITION = _pyiso9660.VD_PARITION
VD_END = _pyiso9660.VD_END
MAX_PUBLISHER_ID = _pyiso9660.MAX_PUBLISHER_ID
MAX_APPLICATION_ID = _pyiso9660.MAX_APPLICATION_ID
MAX_VOLUME_ID = _pyiso9660.MAX_VOLUME_ID
MAX_VOLUMESET_ID = _pyiso9660.MAX_VOLUMESET_ID
STANDARD_ID = _pyiso9660.STANDARD_ID
NOCHECK = _pyiso9660.NOCHECK
SEVEN_BIT = _pyiso9660.SEVEN_BIT
ACHARS = _pyiso9660.ACHARS
DCHARS = _pyiso9660.DCHARS
EXTENSION_JOLIET_LEVEL1 = _pyiso9660.EXTENSION_JOLIET_LEVEL1
EXTENSION_JOLIET_LEVEL2 = _pyiso9660.EXTENSION_JOLIET_LEVEL2
EXTENSION_JOLIET_LEVEL3 = _pyiso9660.EXTENSION_JOLIET_LEVEL3
EXTENSION_ROCK_RIDGE = _pyiso9660.EXTENSION_ROCK_RIDGE
EXTENSION_HIGH_SIERRA = _pyiso9660.EXTENSION_HIGH_SIERRA
EXTENSION_ALL = _pyiso9660.EXTENSION_ALL
EXTENSION_NONE = _pyiso9660.EXTENSION_NONE
EXTENSION_JOLIET = _pyiso9660.EXTENSION_JOLIET

def open_iso(*args):
  """
    open_iso(path)
     Open an ISO 9660 image for reading. Maybe in the future we will have
     mode. None is returned on error.

    """
  return _pyiso9660.open_iso(*args)

def open_ext(*args):
  """
    Open an ISO 9660 image for reading allowing various ISO 9660
     extensions.  Maybe in the future we will have a mode. None is
     returned on error.
    """
  return _pyiso9660.open_ext(*args)

def open_fuzzy(*args):
  """
    Open an ISO 9660 image for reading with some tolerence for positioning
    of the ISO9660 image. We scan for ISO_STANDARD_ID and use that to set
    the eventual offset to adjust by (as long as that is <= i_fuzz).

    Maybe in the future we will have a mode. None is returned on error.

    see iso9660_open
    """
  return _pyiso9660.open_fuzzy(*args)

def iso9660_open_fuzzy_ext(*args):
  """
    Open an ISO 9660 image for reading with some tolerence for positioning
    of the ISO9660 image. We scan for ISO_STANDARD_ID and use that to set
    the eventual offset to adjust by (as long as that is <= i_fuzz).

    Maybe in the future we will have a mode. None is returned on error.

    see open_iso

    """
  return _pyiso9660.iso9660_open_fuzzy_ext(*args)

def ifs_fuzzy_read_superblock(*args):
  """
    Read the Super block of an ISO 9660 image but determine framesize
    and datastart and a possible additional offset. Generally here we are
    not reading an ISO 9660 image but a CD-Image which contains an ISO 9660
    filesystem.

    """
  return _pyiso9660.ifs_fuzzy_read_superblock(*args)

def close(*args):
  """
    Close previously opened ISO 9660 image.
    True is unconditionally returned. If there was an error false would
    be returned.
    """
  return _pyiso9660.close(*args)

def seek_read(*args):
  """
    Seek to a position and then read n bytes. (buffer, size) are
     returned.
    """
  return _pyiso9660.seek_read(*args)

def fs_read_pvd(*args):
  """
    Read the Primary Volume Descriptor for a CD.
    None  is returned if there was an error.
    """
  return _pyiso9660.fs_read_pvd(*args)

def ifs_read_pvd(*args):
  """
    Read the Primary Volume Descriptor for an ISO 9660 image.
    None is returned if there was an error.
    """
  return _pyiso9660.ifs_read_pvd(*args)

def fs_read_superblock(*args):
  """
    Read the Super block of an ISO 9660 image. This is the 
    Primary Volume Descriptor (PVD) and perhaps a Supplemental Volume 
    Descriptor if (Joliet) extensions are acceptable.
    """
  return _pyiso9660.fs_read_superblock(*args)

def ifs_read_superblock(*args):
  """
    Read the Super block of an ISO 9660 image. This is the 
     Primary Volume Descriptor (PVD) and perhaps a Supplemental Volume 
     Descriptor if (Joliet) extensions are acceptable.
    """
  return _pyiso9660.ifs_read_superblock(*args)

def set_dtime(*args):
  """Set time in format used in ISO 9660 directory index record"""
  return _pyiso9660.set_dtime(*args)

def set_ltime(*args):
  """Set 'long' time in format used in ISO 9660 primary volume descriptor"""
  return _pyiso9660.set_ltime(*args)

def get_dtime(*args):
  """
    Get Unix time structure from format use in an ISO 9660 directory index 
    record. Even though tm_wday and tm_yday fields are not explicitly in
    idr_date, they are calculated from the other fields.

    If tm is to reflect the localtime, set 'use_localtime' true, otherwise
    tm will reported in GMT.
    """
  return _pyiso9660.get_dtime(*args)

def get_ltime(*args):
  """
    Get 'long' time in format used in ISO 9660 primary volume descriptor
     from a Unix time structure.
    """
  return _pyiso9660.get_ltime(*args)

def is_dchar(*args):
  """
    Return true if c is a DCHAR - a character that can appear in an an
    ISO-9600 level 1 directory name. These are the ASCII capital
    letters A-Z, the digits 0-9 and an underscore.
    """
  return _pyiso9660.is_dchar(*args)

def is_achar(*args):
  """
    Return true if c is an ACHAR - 
     These are the DCHAR's plus some ASCII symbols including the space 
     symbol.
    """
  return _pyiso9660.is_achar(*args)

def name_translate(*args):
  """
    Convert an ISO-9660 file name that stored in a directory entry into 
     what's usually listed as the file name in a listing.
     Lowercase name, and remove trailing ;1's or .;1's and
     turn the other ;'s into version numbers.

     @param psz_oldname the ISO-9660 filename to be translated.
     @param psz_newname returned string. The caller allocates this and
     it should be at least the size of psz_oldname.
     @return length of the translated string is returned.
    """
  return _pyiso9660.name_translate(*args)

def name_translate_ext(*args):
  """
    Convert an ISO-9660 file name that stored in a directory entry into
     what's usually listed as the file name in a listing.  Lowercase
     name if no Joliet Extension interpretation. Remove trailing ;1's or
     .;1's and turn the other ;'s into version numbers.

     @param psz_oldname the ISO-9660 filename to be translated.
     @param psz_newname returned string. The caller allocates this and
     it should be at least the size of psz_oldname.
     @param i_joliet_level 0 if not using Joliet Extension. Otherwise the
     Joliet level.
     @return length of the translated string is returned. It will be no greater
     than the length of psz_oldname.
    """
  return _pyiso9660.name_translate_ext(*args)

def strncpy_pad(*args):
  """
    Pad string src with spaces to size len and copy this to dst. If
     en is less than the length of src, dst will be truncated to the
     first len characters of src.

     src can also be scanned to see if it contains only ACHARs, DCHARs, 
     7-bit ASCII chars depending on the enumeration _check.

     In addition to getting changed, dst is the return value.
     Note: this string might not be NULL terminated.
    """
  return _pyiso9660.strncpy_pad(*args)

def dirname_valid_p(*args):
  """
    Check that psz_path is a valid ISO-9660 directory name.

     A valid directory name should not start out with a slash (/), 
     dot (.) or null byte, should be less than 37 characters long, 
     have no more than 8 characters in a directory component 
     which is separated by a /, and consist of only DCHARs. 

     True is returned if psz_path is valid.
    """
  return _pyiso9660.dirname_valid_p(*args)

def pathname_isofy(*args):
  """
    Take psz_path and a version number and turn that into a ISO-9660
    pathname.  (That's just the pathname followed by ';' and the version
    number. For example, mydir/file.ext -> MYDIR/FILE.EXT;1 for version
    1. The resulting ISO-9660 pathname is returned.
    """
  return _pyiso9660.pathname_isofy(*args)

def pathname_valid_p(*args):
  """
    Check that psz_path is a valid ISO-9660 pathname.  

    A valid pathname contains a valid directory name, if one appears and
    the filename portion should be no more than 8 characters for the
    file prefix and 3 characters in the extension (or portion after a
    dot). There should be exactly one dot somewhere in the filename
    portion and the filename should be composed of only DCHARs.
      
    True is returned if psz_path is valid.
    """
  return _pyiso9660.pathname_valid_p(*args)

def fs_stat(*args):
  """Return file status for psz_path. None is returned on error."""
  return _pyiso9660.fs_stat(*args)

def fs_stat_translate(*args):
  """
    Return file status for path name psz_path. None is returned on error.
    pathname version numbers in the ISO 9660 name are dropped, i.e. ;1
    is removed and if level 1 ISO-9660 names are lowercased.

    The b_mode2 parameter is not used.
    """
  return _pyiso9660.fs_stat_translate(*args)

def ifs_stat(*args):
  """Return file status for pathname. None is returned on error."""
  return _pyiso9660.ifs_stat(*args)

def ifs_stat_translate(*args):
  """
    Return file status for path name psz_path. undef is returned on error.
    pathname version numbers in the ISO 9660 name are dropped, i.e. ;1 is
    removed and if level 1 ISO-9660 names are lowercased.
    """
  return _pyiso9660.ifs_stat_translate(*args)

def fs_readdir(*args):
  """
    Read psz_path (a directory) and return a list of iso9660_stat_t
    pointers for the files inside that directory.
    """
  return _pyiso9660.fs_readdir(*args)

def ifs_readdir(*args):
  """
    Read psz_path (a directory) and return a list of iso9660_stat_t
    pointers for the files inside that directory.
    """
  return _pyiso9660.ifs_readdir(*args)

def get_application_id(*args):
  """
    Return the PVD's application ID.
    None is returned if there is some problem in getting this.
    """
  return _pyiso9660.get_application_id(*args)

def ifs_get_application_id(*args):
  """
    Get the application ID.  Return None if there
    is some problem in getting this.
    """
  return _pyiso9660.ifs_get_application_id(*args)

def get_joliet_level(*args):
  """Return the Joliet level recognized for p_iso."""
  return _pyiso9660.get_joliet_level(*args)

def get_dir_len(*args):
  """Return the Joliet level recognized for p_iso."""
  return _pyiso9660.get_dir_len(*args)

def iso9660_dir_to_name(*args):
  """Return the directory name stored in the iso9660_dir_t."""
  return _pyiso9660.iso9660_dir_to_name(*args)

def get_preparer_id(*args):
  """
    Return a string containing the preparer id with trailing
    blanks removed.
    """
  return _pyiso9660.get_preparer_id(*args)

def ifs_get_preparer_id(*args):
  """
    Get the preparer ID.  Return None if there is some problem in
     getting this.
    """
  return _pyiso9660.ifs_get_preparer_id(*args)

def get_publisher_id(*args):
  """
    Return a string containing the PVD's publisher id with trailing
     blanks removed.
    """
  return _pyiso9660.get_publisher_id(*args)

def ifs_get_publisher_id(*args):
  """
    Get the publisher ID. Return None if there
    is some problem in getting this.
    """
  return _pyiso9660.ifs_get_publisher_id(*args)

def get_pvd_type(*args):
  """
    Get the publisher ID. Return None if there
    is some problem in getting this.
    """
  return _pyiso9660.get_pvd_type(*args)

def get_pvd_id(*args):
  """
    Get the publisher ID. Return None if there
    is some problem in getting this.
    """
  return _pyiso9660.get_pvd_id(*args)

def get_pvd_space_size(*args):
  """
    Get the publisher ID. Return None if there
    is some problem in getting this.
    """
  return _pyiso9660.get_pvd_space_size(*args)

def get_pvd_block_size(*args):
  """
    Get the publisher ID. Return None if there
    is some problem in getting this.
    """
  return _pyiso9660.get_pvd_block_size(*args)

def get_pvd_version(*args):
  """
    Return the primary volume id version number (of pvd).
    If there is an error 0 is returned.
    """
  return _pyiso9660.get_pvd_version(*args)

def get_system_id(*args):
  """
    Return a string containing the PVD's system id with trailing
     blanks removed.
    """
  return _pyiso9660.get_system_id(*args)

def ifs_get_system_id(*args):
  """
    Get the system ID.  None is returned if there
    is some problem in getting this.
    """
  return _pyiso9660.ifs_get_system_id(*args)

def get_root_lsn(*args):
  """
    Return the LSN of the root directory for pvd.  If there is an error
    INVALID_LSN is returned.

    """
  return _pyiso9660.get_root_lsn(*args)

def get_volume_id(*args):
  """Return the PVD's volume ID."""
  return _pyiso9660.get_volume_id(*args)

def ifs_get_volume_id(*args):
  """
    Get the system ID. None is returned if there
    is some problem in getting this.
    """
  return _pyiso9660.ifs_get_volume_id(*args)

def get_volumeset_id(*args):
  """
    Return the PVD's volumeset ID.
    None is returned if there is some problem in getting this. 

    """
  return _pyiso9660.get_volumeset_id(*args)

def ifs_get_volumeset_id(*args):
  """
    Get the volumeset ID.  None is returned if there
    is some problem in getting this.
    """
  return _pyiso9660.ifs_get_volumeset_id(*args)

def pathtable_init(*args):
  """Zero's out pathable. Do this first."""
  return _pyiso9660.pathtable_init(*args)

def pathtable_get_size(*args):
  """Zero's out pathable. Do this first."""
  return _pyiso9660.pathtable_get_size(*args)

def pathtable_l_add_entry(*args):
  """Zero's out pathable. Do this first."""
  return _pyiso9660.pathtable_l_add_entry(*args)

def pathtable_m_add_entry(*args):
  """Zero's out pathable. Do this first."""
  return _pyiso9660.pathtable_m_add_entry(*args)

def set_evd(*args):
  """Zero's out pathable. Do this first."""
  return _pyiso9660.set_evd(*args)

def is_xa(*args):
  """Return true if ISO 9660 image has extended attrributes (XA)."""
  return _pyiso9660.is_xa(*args)
# This file is compatible with both classic and new-style classes.





#!/usr/bin/env python
"""Program to show CD-ROM device information"""
#
#  Copyright (C) 2006, 2008, 2013 Rocky Bernstein <rocky@gnu.org>
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <http://www.gnu.org/licenses/>.

import os, sys
libdir = os.path.join(os.path.dirname(__file__), '..')
if libdir[-1] != os.path.sep:
    libdir += os.path.sep
sys.path.insert(0, libdir)
import pycdio
import cdio

def sort_dict_keys(dict):
    """Return sorted keys of a dictionary.
    There's probably an easier way to do this that I'm not aware of."""
    keys=list(dict.keys())
    keys.sort()
    return keys

if sys.argv[1:]:
    try:
        drive_name = sys.argv[1]
        d = cdio.Device(sys.argv[1])
    except IOError:
        print("Problem opening CD-ROM: %s" % drive_name)
        sys.exit(1)
else:
    try:
        d = cdio.Device(driver_id=pycdio.DRIVER_UNKNOWN)
        drive_name = d.get_device()
    except IOError:
        print("Problem finding a CD-ROM")
        sys.exit(1)

# Should there should be no "ok"?
ok, vendor, model, release = d.get_hwinfo()

print("drive: %s, vendor: %s, model: %s, release: %s" \
      % (drive_name, vendor, model, release))

read_cap, write_cap, misc_cap = d.get_drive_cap()
print("Drive Capabilities for %s..." % drive_name)

s = "\n\t".join(cap for cap in sort_dict_keys(read_cap) +
                sort_dict_keys(write_cap) + sort_dict_keys(misc_cap))
print "\t%s" % s

print("\nDriver Availability...")
seen = {}
for driver_name in sort_dict_keys(cdio.drivers):
    try: 
        driver_id = cdio.drivers[driver_name]
        if cdio.have_driver(driver_name) and not driver_id in seen:
            print("\tDriver %s (%d) is installed." % (driver_name, driver_id,))
            seen[driver_id] = True
    except ValueError:
        pass
d.close()



#!/usr/bin/env python
"""
distutils setup (setup.py) for pycdio.

This gets a bit of package info from __pkginfo__.py file
"""

# Get the required package information 
from __pkginfo__ import modname, version, license, short_desc, \
     web, author, author_email, classifiers

from setuptools import setup
from distutils.core import setup, Extension
from subprocess import *

import os
import shutil

top_dir = os.path.dirname(os.path.abspath(__file__))
README  = os.path.join(top_dir, 'README.txt')

def rm_file(*paths):
  global top_dir
  toast = os.path.join(top_dir, *paths)
  try:
    os.remove(toast)
  except:
    pass
  return

# Description in package will come from the README file.
long_description = open(README).read() + '\n\n'

# We store swig sources in ./swig, but we want the generated python
# module not to appear in that directory, but instead in the top-level
# directory where we have the other modules. I'd move *all* of the modules
# to their own directory if I knew how to do that in distutils.
swig_opts        = ['-outdir', top_dir]

# Account for API change after 0.83
ge_84 = call(['pkg-config','--atleast-version=0.84','libcdio'])
if ge_84 is 0:
  print("libcdio version > 0.83")
  shutil.copy('swig/cdtext_new.swg','swig/cdtext.swg')  
else:
  print("libcdio version <= 0.83")
  shutil.copy('swig/cdtext_old.swg','swig/cdtext.swg')
  print("Note: you should SWIG installed to build this package")
  for filename in ('ctext.swg', 'pyiso9660.py', 'pycdio.py'):
    rm_file(filename)
    pass
  for filename in ('pyiso9660_wrap.c', 'pycdio_wrap.c'):
    rm_file('swig', filename)
    pass
  pass

# Find runtime library directories for libcdio and libiso9660 using
# pkg-config. Then create the right Extension object lists which later
# get fed into setup()'s list of ext_modules.
modules = []
for lib_name in ('libcdio', 'libiso9660'):
    short_libname = lib_name[3:] # Strip off "lib" from name

    # FIXME: DRY this code.
    try:
        p = Popen(['pkg-config', '--libs-only-L', lib_name], stdout=PIPE)
    except:
        print("** Error trying to run pkg-config. Is it installed?")
        print("** If not, see http://pkg-config.freedesktop.org")
        raise 
        pass

    if p.returncode is None:
        # Strip off blanks and initial '-L'
        dirs = p.communicate()[0].split(b'-L')[1:]
        runtime_lib_dirs = [d.strip() for d in dirs]
    else:
        print(("** Didn't the normal return code running pkg-config," + 
               "on %s. got:\n\t%s" % [lib_name, p.returncode]))
        print("** Will try to add %s anyway." % short_libname)
        runtime_lib_dirs = None
    library_dirs = runtime_lib_dirs
    p = Popen(['pkg-config', '--cflags-only-I', lib_name], stdout=PIPE)
    if p.returncode is None:
	# String starts '-I' so the first entry is ''; Discard that,
	# the others we want.
        dirs = p.communicate()[0].split(b'-I')[1:]
        include_dirs = [d.strip() for d in dirs]
    p = Popen(['pkg-config', '--libs-only-l', lib_name], stdout=PIPE)
    if p.returncode is None:
	# String starts '-l' so the first entry is ''; Discard that,
	# the others we want.
        dirs = p.communicate()[0].split(b'-l')[1:]
        libraries = [d.strip().decode("utf-8") for d in dirs]
        pass
    py_shortname = 'py' + short_libname
    modules.append(Extension('_' + py_shortname,
                             libraries = libraries,
                             swig_opts = swig_opts,
                             include_dirs=include_dirs,
                             library_dirs=library_dirs,
                             runtime_library_dirs=runtime_lib_dirs,
                             sources=['swig/%s.i' % py_shortname]))

setup (author             = author,
       author_email       = author_email,
       classifiers        = classifiers,
       description        = short_desc,
       ext_modules        = modules,
       license            = license,
       long_description   = long_description,
       name               = modname, 
       py_modules         = ['cdio', 'iso9660', 'pycdio', 'pyiso9660'],
       test_suite         = 'nose.collector',
       url                = web,
       version            = version,
       )



#!/usr/bin/env python
"""Program to Eject and close CD-ROM drive"""
#
#  Copyright (C) 2006, 2008, 2013 Rocky Bernstein <rocky@gnu.org>
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <http://www.gnu.org/licenses/>.

import os, sys
libdir = os.path.join(os.path.dirname(__file__), '..')
if libdir[-1] != os.path.sep:
    libdir += os.path.sep
sys.path.insert(0, libdir)
import pycdio
import cdio

if sys.argv[1:]:
    try:
        drive_name=sys.argv[1]
        d = cdio.Device(drive_name)
    except IOError:
        print("Problem opening CD-ROM: %s" % drive_name)
        sys.exit(1)
else:
    try:
        d = cdio.Device(driver_id=pycdio.DRIVER_UNKNOWN)
        drive_name = d.get_device()
    except IOError:
        print("Problem finding a CD-ROM")
        sys.exit(1)

try:
    
    print("Ejecting CD in drive %s" % drive_name)
    d.eject_media()
    try:
        cdio.close_tray(drive_name)
        print("Closed tray of CD-ROM drive %s" % drive_name)
    except cdio.DeviceException:
        print("Closing tray of CD-ROM drive %s failed" % drive_name)

except cdio.DriverUnsupportedError:
    print("Eject not supported for %s" % drive_name)
except cdio.DeviceException:
    print("Eject of CD-ROM drive %s failed" % drive_name)

    

  



#!/usr/bin/env python

""" A simple program to show using libiso9660 to list files in a directory of
   an ISO-9660 image.

   If a single argument is given, it is used as the ISO 9660 image to
   use in the listing. Otherwise a compiled-in default ISO 9660 image
   name (that comes with the libcdio distribution) will be used."""

#  Copyright (C) 2006, 2008, 2013 Rocky Bernstein <rocky@gnu.org>
#  
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <http://www.gnu.org/licenses/>.

import os, sys
libdir = os.path.join(os.path.dirname(__file__), '..')
if libdir[-1] != os.path.sep:
    libdir += os.path.sep
sys.path.insert(0, libdir)
import iso9660

# The default ISO 9660 image if none given
ISO9660_IMAGE_PATH="../data"
ISO9660_IMAGE=os.path.join(ISO9660_IMAGE_PATH, "copying.iso")

if len(sys.argv) > 1:
    iso_image_fname = sys.argv[1]
else:    
    iso_image_fname = ISO9660_IMAGE

iso = iso9660.ISO9660.IFS(source=iso_image_fname)
  
if not iso.is_open():
    print("Sorry, couldn't open %s as an ISO-9660 image." %  iso_image_fname)
    sys.exit(1)

path = '/'

file_stats = iso.readdir(path)

id = iso.get_application_id()
if id is not None: print("Application ID: %s" % id)

id = iso.get_preparer_id()
if id is not None: print("Preparer ID: %s" % id)

id = iso.get_publisher_id()
if id is not None: print("Publisher ID: %s" % id)

id = iso.get_system_id()
if id is not None: print("System ID: %s" % id)

id = iso.get_volume_id()
if id is not None: print("Volume ID: %s" % id)

id = iso.get_volumeset_id()
if id is not None: print("Volumeset ID: %s" % id)

dir_tr=['-', 'd']

for stat in file_stats:
    # FIXME
    filename = stat[0]
    LSN      = stat[1]
    size     = stat[2]
    sec_size = stat[3]
    is_dir   = stat[4] == 2
    print("%s [LSN %6d] %8d %s%s" % (dir_tr[is_dir], LSN, size, path,
                                     iso9660.name_translate(filename)))
iso.close()
sys.exit(0)


